#line 2 "scanner.c"

#line 4 "scanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L &&(!defined(_MSC_VER) || _MSC_VER >= 1800)

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 137
#define YY_END_OF_BUFFER 138
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[1094] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      138,  132,   19,   55,   25,  132,  123,   50,   51,  127,
      128,  129,  122,  126,   52,  124,   56,  130,  125,  131,
      117,  117,  117,  117,  117,  117,  117,  117,  117,  117,
      117,  117,  117,  117,  117,  117,  117,  117,  117,   19,
       55,   21,  128,   60,  129,  122,   52,  128,   65,  129,
       52,  134,   55,   56,  134,   55,  134,  136,   55,  135,
       56,   55,  136,   55,   47,  121,   54,    0,  122,    0,
       52,  117,   56,  118,  120,  119,  117,  117,  117,    0,
        0,    0,  117,  117,  117,  117,  117,  117,  117,  117,

        0,    0,    0,  117,    0,    0,  117,  117,   28,  117,
      117,  117,  117,    0,  117,  117,  117,  117,  117,  117,
      117,  117,  117,   32,  117,  117,  117,  117,    0,    0,
        0,    0,    0,    0,    0,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,    0,   54,   60,   59,    0,
       52,    0,   54,   64,   63,    0,   52,  134,  133,  134,
      134,  134,  134,  134,  134,  134,  134,  135,    0,    0,
        0,    0,    0,    0,    0,    0,   53,  117,  117,    0,
        0,   42,   45,    0,   41,    0,    0,  117,  117,  117,
      117,  117,  117,  117,    0,   40,   49,    0,   39,  117,

        0,   38,    0,   37,  117,  117,  117,   29,  117,    0,
      117,    0,    0,   46,    0,   22,  117,  117,  117,  117,
      117,  117,  117,  117,  117,    0,    0,  117,  117,    0,
       27,   48,    0,   26,    0,   36,    0,   35,    0,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,    0,    0,   57,   53,   64,    0,    0,   61,   53,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  117,  117,    0,    0,    0,    0,   44,    0,
       43,    0,  117,  117,  117,  117,  117,  117,  117,  117,

      117,  117,  117,    0,    0,    0,    0,   31,    0,   30,
        0,    0,    0,    0,  117,  117,  117,  117,  117,  117,
      117,  117,  117,  117,    0,   34,    0,   33,  117,  117,
        0,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   58,   62,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      117,  117,    0,    0,    0,    0,    0,    0,  117,  117,
      117,    0,  117,  117,  117,  117,    0,    0,  117,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,  117,  117,  117,  117,  112,    0,  117,  117,
        0,    0,  113,    0,    0,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  134,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  117,    0,    0,    0,
        0,    0,    0,    0,  117,    0,  117,    0,  117,  117,
      117,  117,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  117,    0,    0,  117,    0,  117,

      117,    0,    0,    0,    0,    0,    0,    0,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   14,  134,  134,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  117,    0,   96,    0,   99,   81,    0,    0,    0,
        0,  117,    0,  117,  117,  102,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   23,    0,    0,    0,    0,  117,    0,    0,    0,

        0,    0,    0,    0,    0,   21,   21,   21,   21,   21,
       21,   20,   21,   21,   21,   21,   21,   21,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  117,    0,    0,    0,    0,    0,
        0,  117,    0,   24,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  103,    0,   95,    0,
       98,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  117,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   21,    3,   21,

        5,   21,   21,   21,   21,    1,   21,    2,   20,   21,
       21,   21,   21,   21,   21,   10,   21,  134,    0,  134,
        0,  134,  134,    0,  134,    0,  134,    0,  134,  134,
      134,  134,  134,  134,    0,  134,    0,    0,    0,    0,
        0,    0,    0,    0,  110,    0,  117,    0,    0,    0,
        0,   78,    0,  117,   69,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  111,  115,    0,    0,    0,    0,    0,   18,
       21,   21,   21,   21,    6,   21,   21,   21,   21,   21,

      134,  134,    0,  134,    0,  134,  134,  134,  134,  134,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   83,
        0,    0,    0,    0,    0,    0,    0,    0,  116,    0,
       77,   77,    0,    0,   80,    0,   86,    0,    0,    0,
        0,    0,    0,    0,   92,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  104,   18,   17,   21,
       21,   13,   21,   21,   21,    8,   21,   21,   21,  134,
      134,  134,    0,  134,    0,  134,  134,  134,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   84,    0,   87,    0,

        0,   90,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   89,    0,    0,    0,    0,   21,   15,   21,
       21,   21,   21,   21,  134,  134,    0,  134,  134,  134,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   66,
        0,    0,    0,    0,  101,    0,    0,    0,    0,    0,
      100,  100,    0,    0,    0,   97,    0,   72,   73,    0,
        0,    0,    0,    0,   21,    4,   21,   12,   21,   21,
       21,    9,  134,    0,  134,  134,  134,  134,    0,    0,
        0,    0,    0,    0,    0,   67,   71,    0,    0,   75,
       75,    0,   82,   85,    0,    0,    0,    0,   94,    0,

       93,    0,    0,    0,    0,    0,    0,   16,   21,   21,
      134,    0,    0,    0,    0,    0,    0,    0,    0,   76,
       76,    0,    0,   91,    0,    0,    0,    0,    0,    0,
        0,    0,   21,    7,   21,  134,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   88,   68,   70,   79,
        0,    0,    0,   11,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   74,   74,    0,    0,    0,    0,  114,
        0,    0,    0,    0,  108,    0,    0,    0,    0,    0,
        0,    0,  109,    0,    0,    0,  107,    0,    0,  105,
        0,  106,    0

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    1,    4,    5,    1,    6,    7,    8,    9,
       10,   11,   12,   13,   14,   15,   16,   17,   17,   18,
       18,   18,   18,   18,   18,   18,   18,   19,   20,   21,
       22,   23,    1,    1,   24,   25,   26,   27,   28,   29,
       30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   43,   44,   45,   46,   47,   48,   49,
        1,    1,    1,    1,   50,    1,   51,   52,   53,   54,

       55,   56,   57,   58,   59,   33,   60,   61,   62,   63,
       64,   65,   66,   67,   68,   69,   70,   71,   72,   73,
       74,   75,    1,    1,    1,    1,    1,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,

       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76
    } ;

static const YY_CHAR yy_meta[77] =
    {   0,
        1,    2,    3,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    4,    1,    1,    5,    5,    1,    6,
        1,    1,    1,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    7,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    7
    } ;

static const flex_int16_t yy_base[1153] =
    {   0,
        0,   75,   69,   86,   93,  110,   94,  114,  173,  249,
     2275, 3474, 3474, 2241, 3474,   75, 3474, 3474, 3474, 2155,
       77,   91,  118, 3474,  118, 3474, 2143,  107, 3474, 2127,
      176,  151,   88,  253,  158,  104,  153,  150,  273,  329,
      226,  177,  192,  389,  183,  271,  280,  230,  270, 2138,
      134,  438,  125, 2101,  132,  332,  344,  199,  328,  278,
      351,    0, 2105, 2086,   83,  157,  484, 3474, 2097,    0,
     2047,  243,  530, 2042,  152, 3474,  204,  312,  351,  193,
      290,  216, 2011, 3474, 3474, 3474,  328,  338,  372, 1999,
      265, 1929,  391,  259,  356,  363,  384,  366,  375,  395,

     1915,    0, 1907,  382, 1909, 1861,  435,  406, 3474,  432,
      405,  529,  443,  355,  510,  444,  538,  520,  417,  469,
      476,  526,  500, 3474,  495,  561,  550,  560, 1852,    0,
     1812, 1811, 1802,  278,    0,    0,  574,  339,  432,  436,
      512,  284,  550,  554,  542,  590,  602, 1702,  596,  618,
      608,  620,  411, 1697,  622,  642,  648,    0,    0,  622,
      619,  616,  622,  589,  640,  619,  587,    0,  641,  628,
      641,  648,  640,  660,  652,  640,  674,  672,  687,  700,
     1702, 3474,  499, 1650, 3474, 1614, 1601,  716,  709,  698,
      712,  703,  718,  727, 1560, 3474,    0, 1525, 3474,  732,

     1521, 3474, 1506, 3474,  724,  707,  736, 3474,  720,  777,
      782, 1478, 1454,  573,  831,  744,  785,  786,  792,  795,
      793,  811,  803,  774,  815, 1382, 1360,  840,  824, 1357,
     3474,    0, 1347, 3474, 1333, 3474, 1314, 3474,  706,  718,
      748,  750,  758,  801,  803,  824,  832,  824,  832,  835,
      822,  883,  798,  887,  892, 1301,  862,  809,  895,  901,
      866,  868,  843,  882,  892,  890,  898,  888,  899,  899,
      889,  904,  904,  892,  901,  908,  905,  916,  906,  913,
      917,  904,  933,  943,  925,  938,  928, 1302, 3474, 1284,
     3474,  975,  955,  968,  958, 1019,  977,  985,  980,  993,

     1045, 1047, 1050,  958,  962, 1114, 1273, 3474, 1267, 3474,
      956,  989,  935, 1013, 1024, 1028, 1037, 1043, 1105, 1108,
     1042, 1087, 1130, 1146, 1268, 3474, 1250, 3474, 1161, 1181,
     1027, 1062, 1061, 1064, 1038, 1044, 1086, 1096, 1090, 1093,
     1095, 1109, 1115, 1130, 1008, 1073, 1145, 1146, 1140, 1142,
     1153, 1161, 1150, 1150, 1157, 1164, 1164, 1167, 1165, 1184,
     1177, 1180, 1184, 1182, 1179, 1179, 1181, 1187, 1187, 1190,
     1241, 1215, 1191, 1212, 1199, 1203, 1206, 1215, 1260, 1281,
     1243, 1285, 1257, 1253, 1265, 1282, 1316, 1331, 1343, 1340,
     1214, 1256, 1257, 1327, 1267, 1304, 1258, 1294, 1295, 1262,

     1295, 1303, 1348, 1374, 1399, 1359, 3474, 1401, 1392, 1368,
     1414, 1433, 3474, 1438, 1357, 1316, 1359, 1357, 1381, 1394,
     1393, 1427, 1386, 1409, 1408, 1407, 1425, 1422, 1238, 1426,
     1422, 1413, 1430, 1442, 1440, 1434, 1445, 1442, 1437, 1441,
     1435, 1488, 1441, 1437, 1469, 1467, 1478, 1478, 1470, 1485,
     1480, 1475, 1479, 1473, 1203, 1526, 1506, 1476, 1545, 1548,
     1564, 1486, 1488, 1567, 1569, 1572, 1541, 1486, 1548, 1574,
     1576, 1593, 1535, 1547, 1561, 1614, 1556, 1570, 1577, 1580,
     1642, 1581, 1560, 1596, 1603, 1566, 1648, 1604, 1597, 1609,
     1614, 1604, 1607, 1624, 1639, 1668, 1673, 1682, 1613, 1649,

     1684, 1649, 1623, 1644, 1655, 1654, 1659, 1135, 1655, 1664,
     1672, 1670, 1678, 1669, 1252, 1518, 1665, 1690, 1687, 1688,
     1694, 1694, 1166, 3474, 1679, 1688, 1697, 1694, 1698, 1692,
     1692, 1719, 1712, 1713, 1725, 1725, 1756, 1145, 1715, 1725,
     1723, 1726, 1733, 1724, 1720, 1741, 1737, 1741, 1747, 1747,
     1751, 1764, 1744, 3474, 1745, 3474, 3474, 1758, 1755, 1749,
     1747, 1781, 1754, 1785, 1823, 1826, 1839, 1847, 1779, 1770,
     1775, 1783, 1789, 1800, 1804, 1817, 1855, 1869, 1881, 1885,
     1827, 1835, 1841, 1905, 1814, 1838, 1846, 1847, 1907, 1850,
     1919, 1928, 1850, 1861, 1932, 1873, 1909, 1946, 1890, 1869,

     1900, 1899, 1903, 1954, 1914, 1137,  482, 1925, 1123, 1086,
     1084,    0, 1913, 1928, 1934, 1939, 1034,  679, 1980, 1984,
     1940, 1078, 1987, 1989, 1934, 1949, 1952, 1957, 1027, 2010,
     1073,  796, 1966, 1063, 1032, 1017, 1959, 1973, 1974, 1978,
      959, 1325, 2014, 1982, 2005, 1974, 1985, 1975, 1979, 2036,
     1991, 2011, 2050, 1140, 2055, 2069, 1994, 2077, 2003, 2005,
     2074, 2000, 2008, 2015, 2026, 2057, 3474, 2054, 3474, 2024,
     3474, 2039, 2047, 2060, 2054, 2054, 2055, 2113, 2079, 2059,
     2128, 2074, 2134, 2089, 2099, 2082, 2100, 2142, 2157, 2166,
     2104, 2108, 2122, 2121, 2137, 2187,  994,  985, 3474,  979,

     3474, 2140, 2145, 1354,  936, 3474,  931, 3474,    0,  927,
     2152, 2157, 2159, 2124,  923, 3474, 2149, 2193,  914, 2201,
      890, 2203, 2171, 1414, 2213,  879, 2216,  868, 2223, 2170,
     2192, 2194, 2160, 2228,  865, 2237, 2192, 2201,  821, 2198,
     2204, 2209, 2192, 2240, 3474, 2218, 2248, 2250,  794, 2226,
     2242, 3474, 2212, 2274, 3474, 2228, 2241, 2246, 2287, 2238,
     2307, 2237, 2310, 2248, 2313, 2253, 2329, 2252, 2285, 2291,
     2260, 2289, 2290, 2337, 2353, 2302, 2299, 2290, 2317, 2319,
     2315, 2313, 3474, 3474, 2323, 2322, 2335, 2326, 2374, 1802,
     2358, 2335,  803,  714, 3474, 2343,  703, 1860, 2347, 2379,

     2380, 2351,  695, 2388,  632, 2360,  599, 2404, 2371, 2394,
     2401, 2370, 2377,  593, 1902, 2381, 2408, 2373, 2426, 3474,
     2377, 2379, 2383, 2377, 2452, 2454, 2389, 2385, 3474, 2390,
     2473, 3474, 2479, 2397, 3474, 2482, 3474, 2425,  525, 2488,
     2399, 2414, 2442, 2442, 3474, 2449, 2443, 2460, 2443, 2445,
     2461, 2514, 2486, 2486, 2470, 2472, 3474, 2516, 3474, 2516,
      527, 3474, 2494,  489,  502, 3474, 2519, 2482, 2523, 2542,
      486, 2498,  469, 2551,  469, 2553, 2485, 2555, 2536,  464,
     2506, 2526, 2499, 2558, 2503, 2510, 2540, 2530, 2586, 2534,
     2540, 2595, 2542, 2611, 2541, 2614, 3474, 2545, 3474, 2553,

     2564, 3474, 2573, 2633, 2572, 2578, 2588, 2652, 2595, 2655,
     2661, 2589, 3474, 2590, 2596, 2612, 2606,  461, 3474, 2626,
      412, 2630, 2623,  409, 2677, 2628,  406, 2680, 2639, 2682,
      349, 2655, 2669, 2652,  329, 2659, 2656, 2664, 2693, 3474,
     2707, 2661, 2664, 2726, 3474, 2670, 2730, 2745, 2683, 2674,
     2749, 3474, 2751, 2676, 2765, 3474, 2697, 3474, 3474, 2706,
     2718, 2713,  303, 2727,  304, 3474,  295, 3474, 2757,  289,
      286, 3474, 2770,  237,  227, 2772,  215, 2774,  213,  208,
     2777,  201, 2748, 2745, 2760, 3474, 3474, 2764, 2749, 2794,
     3474, 2814, 3474, 3474, 2765, 2822, 2837, 2773, 3474, 2769,

     3474, 2785, 2786, 2773,  152, 2788, 2778, 3474,  161, 1514,
     2841, 2279,  150, 2801, 2803, 2850, 2813, 2824, 2866, 2871,
     3474, 2874, 2823, 3474, 2806, 2890, 2893, 2896, 2916, 2818,
     2853, 2825,  146, 3474,  142, 2918,  139,  129, 2921, 2865,
     2858, 2867, 2930, 2884, 2942, 2950, 3474, 3474, 3474, 3474,
     2881, 2898, 2899, 3474, 2862, 2905, 2956, 2964, 2910, 2919,
       76, 2980, 2911, 2983, 3474, 2989, 2929, 3003, 2970, 3474,
     2950, 3008, 2950, 2962, 3474, 2984, 2988, 3017, 3040, 2960,
     2986, 2996, 3474, 3043, 3006, 2992, 3474, 3063, 3012, 3474,
     3066, 3474, 3474, 3086, 3093, 3097, 3104, 3111, 3115, 3120,

     3127, 3134,   80, 3141, 3148, 3155, 3162,   74, 3169, 3176,
     3183, 3190, 3197, 3204, 3211, 3218, 3225, 3232, 3239, 3246,
     3251, 3256, 3263, 3270, 3277, 3284, 3291, 3298, 3305, 3312,
     3319, 3326, 3333, 3340, 3347, 3354, 3361, 3368, 3375, 3382,
     3389, 3396, 3403, 3410, 3417, 3424, 3431, 3438, 3445, 3452,
     3459, 3466
    } ;

static const flex_int16_t yy_def[1153] =
    {   0,
     1093,    1,    1,    1,    1,    1, 1094, 1094, 1095, 1095,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1096, 1093, 1093, 1093, 1093, 1093,
     1096, 1096, 1096, 1096, 1096, 1096, 1096, 1096, 1096, 1096,
     1096, 1096, 1096, 1096, 1096, 1096, 1096, 1096, 1096, 1093,
     1093, 1097, 1093, 1093, 1093, 1093, 1096, 1093, 1093, 1093,
     1096, 1098, 1093, 1093, 1098, 1093, 1098, 1093, 1093, 1099,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1096,
     1096, 1096, 1093, 1093, 1093, 1093, 1096, 1096, 1096, 1100,
     1093, 1101, 1096, 1096, 1096, 1096, 1096, 1096, 1096, 1096,

     1102, 1103, 1104, 1096, 1105, 1106, 1096, 1096, 1093, 1096,
     1096, 1096, 1096, 1093, 1096, 1096, 1096, 1096, 1096, 1096,
     1096, 1096, 1096, 1093, 1096, 1096, 1096, 1096, 1107, 1108,
     1109, 1110, 1111, 1093,   73, 1097, 1097, 1097, 1097, 1097,
     1097, 1097, 1097, 1097, 1097, 1093, 1093, 1093, 1093, 1093,
     1096, 1093, 1093, 1093, 1093, 1093, 1096, 1098, 1098, 1098,
     1098, 1098, 1098, 1098, 1098, 1098, 1098, 1099, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1096, 1096, 1096, 1093,
     1100, 1093, 1093, 1101, 1093, 1112, 1113, 1096, 1096, 1096,
     1096, 1096, 1096, 1096, 1102, 1093, 1103, 1104, 1093, 1096,

     1105, 1093, 1106, 1093, 1096, 1096, 1096, 1093, 1096, 1093,
     1096, 1114, 1115, 1093, 1093, 1096, 1096, 1096, 1096, 1096,
     1096, 1096, 1096, 1096, 1096, 1116, 1117, 1096, 1096, 1107,
     1093, 1108, 1109, 1093, 1110, 1093, 1111, 1093, 1093, 1097,
     1097, 1097, 1097, 1097, 1097, 1097, 1097, 1097, 1097, 1097,
     1097, 1093, 1093, 1093, 1096, 1093, 1093, 1093, 1093, 1096,
     1098, 1098, 1098, 1098, 1098, 1098, 1098, 1098, 1098, 1098,
     1098, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1096, 1096, 1093, 1093, 1093, 1112, 1093, 1113,
     1093, 1093, 1096, 1096, 1096, 1096, 1096, 1096, 1096, 1096,

     1096, 1096, 1096, 1093, 1093, 1093, 1114, 1093, 1115, 1093,
     1093, 1093, 1093, 1093, 1096, 1096, 1096, 1096, 1096, 1096,
     1096, 1096, 1096, 1096, 1116, 1093, 1117, 1093, 1096, 1096,
     1093, 1097, 1097, 1097, 1097, 1097, 1097, 1097, 1097, 1097,
     1097, 1097, 1097, 1097, 1093, 1093, 1098, 1098, 1098, 1098,
     1098, 1098, 1098, 1098, 1098, 1098, 1098, 1098, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1096, 1096, 1093, 1093, 1093, 1093, 1093, 1093, 1096, 1096,
     1096, 1093, 1096, 1096, 1096, 1096, 1093, 1093, 1096, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,

     1093, 1093, 1096, 1096, 1096, 1096, 1093, 1093, 1096, 1096,
     1093, 1093, 1093, 1093, 1093, 1097, 1097, 1097, 1097, 1097,
     1097, 1097, 1097, 1097, 1097, 1097, 1097, 1097, 1118, 1098,
     1098, 1098, 1098, 1098, 1098, 1098, 1098, 1098, 1098, 1098,
     1098, 1119, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1120, 1093, 1096, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1096, 1093, 1096, 1093, 1096, 1096,
     1096, 1096, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1096, 1093, 1093, 1096, 1093, 1096,

     1096, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1097, 1097,
     1097, 1097, 1097, 1097, 1097, 1097, 1097, 1097, 1097, 1097,
     1097, 1097, 1118, 1093, 1098, 1098, 1098, 1098, 1098, 1098,
     1098, 1098, 1098, 1098, 1098, 1098, 1119, 1120, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1096, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1096, 1093, 1096, 1096, 1096, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1096, 1093, 1093, 1093, 1093, 1096, 1121, 1093, 1093,

     1093, 1093, 1093, 1093, 1093, 1122, 1123, 1097, 1097, 1124,
     1125, 1126, 1097, 1097, 1097, 1097, 1097, 1127, 1128, 1129,
     1098, 1098, 1130, 1131, 1098, 1098, 1098, 1098, 1098, 1132,
     1133, 1134, 1093, 1093, 1135, 1136, 1093, 1093, 1093, 1093,
     1093, 1137, 1093, 1093, 1096, 1093, 1093, 1093, 1093, 1093,
     1093, 1096, 1093, 1096, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1096, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1122, 1093, 1123,

     1093, 1123, 1097, 1097, 1124, 1093, 1125, 1093, 1126, 1138,
     1097, 1097, 1097, 1097, 1127, 1093, 1127, 1128, 1133, 1129,
     1134, 1129, 1098, 1093, 1130, 1135, 1131, 1136, 1139, 1098,
     1098, 1098, 1098, 1132, 1137, 1132, 1134, 1093, 1140, 1093,
     1093, 1093, 1093, 1137, 1093, 1093, 1096, 1093, 1093, 1093,
     1093, 1093, 1093, 1096, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1123, 1097, 1097, 1138, 1093, 1097, 1097, 1141, 1097, 1127,

     1129, 1098, 1093, 1139, 1140, 1098, 1098, 1142, 1098, 1132,
     1134, 1093, 1093, 1093, 1143, 1093, 1137, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1123,
     1097, 1093, 1097, 1097, 1141, 1093, 1141, 1097, 1127, 1129,
     1098, 1098, 1093, 1142, 1143, 1142, 1098, 1132, 1134, 1093,
     1093, 1143, 1093, 1137, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,

     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1144, 1093, 1097,
     1097, 1141, 1097, 1145, 1146, 1098, 1093, 1142, 1098, 1147,
     1148, 1093, 1143, 1093, 1149, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1144, 1093, 1097, 1093, 1141, 1097,
     1145, 1093, 1146, 1148, 1098, 1142, 1098, 1147, 1149, 1093,
     1143, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,

     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1150, 1097,
     1151, 1093, 1152, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1150, 1093, 1097, 1151, 1152, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093,    0, 1093, 1093, 1093, 1093, 1093, 1093, 1093,

     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093
    } ;

static const flex_int16_t yy_nxt[3551] =
    {   0,
       12,   13,   14,   15,   12,   16,   17,   15,   18,   19,
       20,   21,   12,   22,   23,   24,   25,   25,   26,   27,
       28,   29,   30,   31,   32,   33,   33,   34,   35,   36,
       37,   38,   33,   33,   39,   33,   40,   41,   42,   33,
       43,   44,   45,   46,   33,   47,   48,   33,   49,   12,
       31,   32,   33,   33,   34,   35,   36,   37,   38,   33,
       39,   33,   40,   41,   42,   33,   43,   44,   45,   46,
       33,   47,   48,   33,   49,   33,   50,   51,  232,   52,
       53,   54,   55,   56,  197,   57,   57,   50,   51, 1069,
       52,   75,   75,   77,   77,   13,   63,   53,   54,   55,

       56,   80,   57,   57,   58,   59,   60,   77,   77,   61,
       61,   50,   51,   64,   52,   50,   66,   80,   67,   78,
       78,   58,   59,   60,  159,   65,   61,   61,   84,   85,
     1054,   80,   79,   64,   81,   81,   74,   80,  135,  146,
     1034,  147,  147, 1054,  100,   65,  146, 1034,  147,  147,
      159, 1034,   65,   80,   90,   91,  101,  102,   92,   74,
      103,  135, 1034,   80,   80, 1030,   80,   80,   75,   75,
      100,   80,   65,   68,   13,   69,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,  104,   68,   68,   80,
       80,   68,   71,   68,   68,   68,   80,   93,   98,   80,

       80,   99,   80, 1012,   87,   80,   80,   80,  116, 1008,
       88,  152,  104,  123,  972,  153,  153, 1012,   89,  117,
       77,   77,   68,   93,   98,   80,   80,   99, 1008,   80,
      114,   87,   80,  129,  130,  116,   88,  131,  966,   80,
      123,   80,   80,   80,   89,   74,  117,  135,   68,   68,
       50,   72,   68,   73,   68,   68,   68,   68,   68,   68,
       68,   68,  115,   68,   68,   80,   80,   68,   71,   68,
       68,   68,   80,  132,  124,   80,  105,  133,  124,   80,
      106,  183,  183,   80,   80,  188,   80,  972,  115,   94,
      152, 1010,   95,   80,  153,  153, 1008,   96,   68,   97,

      107,  239,   80,   80,  108,  966,  177,  177,   80,  125,
      127,  128,  188,   78,   78,   94, 1006,  126,   95,   80,
       80,  247,   80,   96,   68,   97,   79,  107,  239,   80,
      972,  108,  109,   78,   78,  125,  109,  127,  128,   80,
      154,   80,   80,  126,  155,  155,   79,  247,  149,  149,
      966,   80,   78,   78,  110,  156,  111,   80,  146,  150,
      151,  151,  243,  152,   80,   79,  112,  157,  157,   80,
      178,  214,  214,  180,  180,  113,   80,   80,   80,   80,
      179,  110,  156,  111,  180,   80,  150,   80,   80,  243,
      190,  180,  112,   80,  186,   80,  178,   80,  187,  189,

       80,  113,   80,  192,   80,   80,  179,  968,   80,  191,
      972,  193,   80,  968,  118,   80,  119,  190,   80,   80,
      120,   80,  194,  152,   80,  189,  200,  153,  153,  192,
       80,   80,  121,   80,  122,  208,  191,  193,   80,  208,
       80,  118,  207,  119,   80,   80,  212,  120,   80,  194,
      213,  209,  200,  220,   80,   80,   80,   80,  121,  244,
      122,  137,  966,  138,  139,  919,   80,  245,  207,  216,
      866,  205,  140,  141,  142,  143,  206,  209,  144,  220,
      145,   80,   80,  701,   80,  927,  244,  919,  137,   80,
      138,  139,   80,   80,  245,  702,  216,  205,  140,  141,

      142,  143,  206,  866,  144,  921,  145,  160,   80,  161,
      162,  215,  215,   80,  222,  183,  183,  221,   80,  163,
      164,  165,  215,   80,  166,   80,  167,  224,  919,  215,
      210,  210,  225,   80,  160,  246,  161,  162,  901,   80,
      222,  210,   80,  221,   80,  163,  164,  165,  210,   80,
      166,   80,  167,  169,  224,  170,  171,  223,  225,   80,
      219,  217,  246,   80,  226,  172,  173,  174,  227,   80,
      175,  211,  176,   80,   80,   80,  248,  228,   80,  218,
      169,  250,  170,  171,  223,  251,  219,   80,  217,  214,
      214,  172,  173,  174,  249,  873,  175,  211,  176,   80,

      240,  873,  229,  248,  228,  218,  149,  149,  250,   80,
       80,  251,  149,  149,  241,  242,  146,  150,  147,  147,
      249,   80,  146,  150,  255,  255,  267,  240,  229,  252,
      271,  252,  253,  795,  254,  254,  155,  155,  155,  155,
      241,  242,  264,  265,  150,  266,  270,  156,  261,  156,
      150,  275,  267,  257,  258,  257,  271,   80,  259,  259,
      152,   80,  262,  263,  260,  260,  268,  272,  276,  264,
      265,  277,  266,  270,  156,  261,  156,  278,  275,  281,
      716,  273,  274,  282,  269,   80,  279,   80,  262,  263,
      177,  177,  717,  268,  272,  276,  862,   80,  277,  283,

       80,  180,  180,  278,  280,  864,  281,  273,  274,  282,
      269,   80,  180,  279,  284,  795,   80,  292,  292,  180,
       80,   80,   80,   80,  285,   80,  283,  286,  292,   80,
      280,   80,  293,   80,  294,  292,   80,   80,  296,  295,
       80,  284,  287,  297,  332,   80,  331,   80,  301,   80,
      298,  285,   80,  300,  286,  299,   80,   80,   80,  293,
      294,   80,  303,  302,  296,   80,  295,   80,  287,   80,
      297,  332,  331,   80,  301,  333,   80,  298,  210,  210,
      300,   80,  299,  306,  306,   80,  315,   80,  303,  210,
      302,  334,  335,   80,  306,   80,  210,  701,   80,   80,

      304,  306,  333,  305,  862,   80,   80,  821,   80,  737,
      323,  316,  315,  317,  345,  345,   80,  334,  335,  318,
      320,  319,  795,   80,   80,  346,  346,  304,   80,  336,
      305,   80,  215,  215,   80,   80,  323,   80,  316,  337,
      317,   80,   80,  215,   80,  322,  318,  320,  319,  321,
      215,  324,   80,   80,  330,  339,  336,  338,  311,  341,
       80,  340,  344,  342,   80,  337,  716,  312,  313,  708,
      343,  322,  314,   80,  258,  321,  329,  324,  259,  259,
      706,  330,  339,  338,  349,  311,  341,  340,  344,   80,
      342,  701,  347,  312,  313,  348,  343,  253,  314,  254,

      254,  253,  329,  254,  254,   80,  146,  258,  255,  255,
      349,  259,  259,  152,   80,  699,  350,  260,  260,  347,
      351,  353,  348,  352,  716,  354,  355,  356,  795,  358,
      359,  360,  708,  361,  357,  362,  363,  706,  364,  365,
      367,   80,  350,  366,  370,  368,   80,  351,  353,  352,
       80,  354,  369,  355,  356,  358,   80,  359,  360,  361,
      357,  362,  373,  363,  364,  376,  365,  367,   80,  366,
      370,   80,  368,  371,  374,  375,  292,  292,  369,  401,
      701,   80,   80,  372,  391,  392,  699,  292,  373,  379,
       80,  376,   80,   80,  292,  790,  381,  398,   80,  371,

      374,  375,  399,  377,   80,  401,   80,   80,  743,  372,
      380,  391,  392,  378,  385,  379,  400,   80,  708,  383,
      382,  382,  381,  398,  345,  345,   80,  384,  399,   80,
      377,  382,   80,  706,   80,  386,  380,   80,  382,  378,
      385,   80,   80,  400,  402,  383,  387,  387,  388,  388,
       80,  390,  390,  384,  415,   80,   80,  387,   80,  388,
       80,  386,  390,   80,  387,  724,  388,  403,   80,  390,
      406,  402,  420,   80,  699,  404,  733,   80,  421,  405,
      724,  415,  409,  714,  418,  708,   80,  706,  389,  346,
      346,   80,   80,  403,   80,  419,   80,  406,  420,   80,

       80,  404,  416,  417,  421,  405,  407,  407,  409,  408,
      408,  418,  410,  422,  389,  306,  306,  407,   80,  407,
      408,   80,  419,  423,  407,  704,  306,  408,  416,  417,
      424,  411,  411,  306,  425,  426,   80,  393,  699,  410,
      422,  394,  411,   80,  427,  395,  524,  412,  412,  411,
      423,  396,  428,   80,   80,  397,  424,   80,  412,   80,
      425,  426,  413,  413,  393,  412,  429,  524,  394,  432,
      427,  433,  395,  413,   80,  413,  434,  396,  428,   80,
      413,  397,  414,  414,  605,  430,  431,  435,  436,   80,
      437,  438,  429,  414,   80,   80,  432,  439,  433,  440,

      414,  441,  434,  442,  524,  443,  444,  445,  446,  449,
       80,  430,  431,  435,  447,  436,  437,  438,  448,  450,
      451,  452,  453,  439,  454,  440,  455,  441,   80,  442,
       80,  443,  444,  458,  445,  446,  449,  460,  459,  524,
      447,  461,  456,  456,  448,  450,  451,  452,  453,  462,
      454,  457,  455,  456,   80,  463,   80,  328,  479,  458,
      456,  464,  464,  460,   80,  459,   80,  461,  516,  516,
       80,  326,  464,   80,  310,  462,  308,  457,   80,  464,
      470,  463,  466,  466,  479,  467,  382,  382,  469,  489,
       80,  291,   80,  466,   80,   80,  471,  382,  480,  481,

      466,  465,   80,  486,  382,  289,   80,  470,  492,   80,
      468,  467,  472,  256,   80,  469,  489,  387,  387,  490,
      491,  238,  493,  471,  480,  481,  716,  465,  387,  486,
       80,   80,  388,  388,  492,  387,  236,  468,  744,  472,
      487,  390,  390,  388,  476,  476,  490,  491,  488,  493,
      388,  494,  390,  473,  234,  476,   80,  509,  474,  390,
      231,   80,  476,  482,  483,  475,  487,  328,  484,  477,
      793,  793,   80,  485,  488,  496,  496,  494,  478,  473,
      508,   80,  511,  509,  474,  326,  496,   80,  495,  482,
      483,  475,   80,  496,  484,  498,  477,   80,  501,  485,

      497,  497,  408,  408,  478,   80,  510,  508,   80,  511,
      512,  497,   80,  408,  495,  411,  411,   80,  497,  500,
      408,  498,  513,   80,  514,  501,  411,  517,  499,  515,
      803,  803,  510,  411,  412,  412,  518,  512,  527,  414,
      414,   80,  519,  516,  516,  412,  500,  520,   80,  513,
      414,  514,  412,  517,  502,  499,  503,  414,  504,  528,
      505,  310,  521,  518,  506,  527,  522,  525,  519,  526,
      529,  530,  532,  520,  507,  531,  533,  534,  535,  536,
      502,  308,  539,  503,  540,  504,  528,  505,  521,  524,
      538,  506,  522,  525,  541,  526,  542,  529,  530,  532,

      507,  531,  533,  534,  535,  536,  543,  538,  539,  544,
      540,  545,  546,  204,  547,  548,  549,  550,  553,   80,
      612,  541,  558,  542,  202,  559,  563,  456,  456,  552,
     1035, 1035,  199,  543,  516,  516,  544,  545,  456,  546,
      547,  548,  549,  550,  553,  456,  554,  554,  558,  556,
      556,  559,  563,  551,   80,   80,  552,  554,  555,  554,
      556,   80,  556,  196,  554,  557,  557,  556,  464,  464,
      464,  464,  562,  466,  466,  568,  557,  569,  557,  464,
      551,  464,   80,  557,  466,  564,  464,   80,  464,   80,
       80,  466,  570,  575,  567,  567,  574,   80,  580,  562,

      576,  568,  566,  577,  569,  567,   80,  579,  291,  560,
      583,  564,  567,  561,  565,  476,  476,  289,   80,  570,
      575,  581,  574,   80,  580,   80,  476,  576,  582,  566,
      577,  585,  587,  476,  579,  560,  583,  571,  572,  561,
      565,  588,   80,  578,  578,  586,  589,  590,  581,  584,
      584,  591,   80,  596,  578,  582,  573,  185,  585,  587,
      584,  578,   80,  600,  571,  572,  592,  584,  588,  496,
      496,  586,  589,  590,  497,  497,  599,  603,  591,  596,
      496,  601,  573,  595,  595,  497,  598,  496,   80,  600,
      597,  602,  497,  592,  595,   80,  604,   80,   80,  606,

      607,  595,  608,  599,  603,  182,  609,  601,  610,  256,
      593,  611,  613,  614,  148,  594,  597,  602,  615,  616,
      617,  618,  604,  619,  620,  606,  607,  621,  623,  608,
      622,   80,  609,   80,  624,  610,  593,  611,  613,  625,
      614,  594,  626,  627,  628,  615,  616,  617,  618,  619,
      620,  629,  630,  633,  621,  623,  622,  524,  538,  631,
      624,  632,  634,  635,  638,  625,  636,  637,  639,  626,
      627,  628,  640,  641,  642,  538,  643,   80,  629,  630,
      633,  646,  647,  648,  649,  631,  650,  632,  634,  651,
      635,  638,  636,  637,   80,  639,  653,  644,   80,  640,

      641,  642,  659,  643,  858,  660,  645,  646,  647,  238,
      648,  649,  650,   80,  236,  651,  859,  661,  652,  234,
      662,  654,  653,  644,  655,  655,  663,  656,  656,  659,
       80,  660,  645,  665,   80,  655,   80,  664,  656,   80,
      567,  567,  655,  661,  652,  656,  662,  654,  658,  658,
      672,  567,  663,  666,  677,  231,  667,  667,  567,  658,
      665,  866,  673,  664,  674,  678,  658,  667,  204,  667,
      578,  578,   80,  867,  667,   80,  657,  672,  682,  666,
      677,  578,  669,  669,  679,  680,  671,  671,  578,  673,
      684,  674,  678,  669,  670,  669,  668,  671,  692,  671,

      669,  685,  657,  866,  671,  682,  584,  584,  681,  681,
      679,  680,  202,  687,  199,  882,  684,  584,  196,  681,
      408,  408,   80,  668,  584,  692,  681,  685,  691,  683,
      683,  408,  675,  595,  595,  693,  185,  697,  408,  687,
      683,   80,  676,  694,  595,  695,  397,  683,  598,  710,
      688,  595,  703,  711,  691,  696,  696,  686,   80,  675,
      712,  693,  689,  689,  697,  713,  696,  723,  676,  694,
      729,  695,  397,  696,  730,  710,  688,   80,  731,  703,
      711,  699,  719,  732,  686,  701,  721,  712,  706,  726,
      708,  728,  713,  738,  723,  739,  729,  722,  740,  719,

      741,  730,  182,  721,  742,  731,  726,  746,  728,  748,
      732,  716,  735,  749,  753,  745,  745,  750,   80,  751,
      738,  739,  759,  736,   80,  740,  745,  741,  745,  735,
       83,  742,  747,  745,  746,  748,  762,  752,  752,  761,
      749,  753,  764,  750,   74,  751,  765,  754,  752,  759,
      752,  755,  755,  767,   80,  752,  655,  655,  766,  747,
       80,  769,  755,  762,  755,  761,   83,  655,  764,  755,
      656,  656,  765,  754,  655,  763,  763,  770,  658,  658,
      767,  656,  768,  773,  766,  771,  763,  769,  656,  658,
      482,  483,  756,  763,  772,  484,  658,  757,  488,   74,

      485,  776,  758,  770,  760,   83,  775,   74,  777,  768,
      773,  771,  779,  148,  774,  774,  482,  483,  756,  781,
      772,  484,  780,  757,  488,  774,  485,  776,  758,  681,
      681,  760,  774,  775,  777,  683,  683,  782,  785,  779,
      681,  701,  134,  783,  783,  781,  683,  681,   86,  780,
      716,  786,  788,  683,  783,   80,  783,  787,  784,  784,
      789,  783,   83,  782,  785,   76,  478,  784,  784,  784,
      792,  784,  799,  690,  690,  778,  784,  786,  784,  788,
      784,  791,  796,  787,  797,  784,  798,  789,  696,  696,
      800,   80,  478,  701,  699,  719,  802,  792,  799,  696,

      806,  778,  701,  721,  701,  721,  696,  791,  809,  796,
      304,  797,  719,  798,  706,  726,  800,  708,  728,  807,
      721,  808,  721,  802,  795,  805,  812,  806,  813,  716,
      735,  814,  726,  811,  809,  728,  815,  304,  716,  735,
      816,  716,  805,   74,  801,  818,  807,  735,  808,  819,
      819,  820,  820,  812,  824,  813,  735,  822,  814,  811,
      819,   80,  820,  815,  820,  823,  816,  819,  826,  820,
      801,  827,  818,  828, 1093,  825,  825,  830,  810,  833,
      824,  817, 1093,  838,  822, 1093,  825,   80,  829,  829,
      834,  836,  823,  825,  826, 1038, 1038,   80,  827,  829,

      828,  829,  841,  830,  810,  833,  829,  817,  831,  831,
      838,  763,  763,  839,  835,  835,  834,  836,  840,  831,
      842,  832,  763,   80,  843,  835,  831,  835,  841,  763,
      837,  837,  835,  846,  572, 1093,  847,  848,  774,  774,
      839,  837,  849,  837,  850,  840,  853,  842,  837,  774,
      843,  851,  573,  852,  845,  845,  774,  854,  855,  701,
      846,  572,  847,  848,  844,  845,  856,  845,  861,  849,
      863,  850,  845,  853,  868,  857,  857,  851,  573,  852,
      716,  701,  721,  854,  871,  855,  857,  872,  857,  795,
      805,  844,  856,  857,  861,  716,  735,  863,  877,  721,

      860,  868,  701,  880,  881,  866,  875,  805,  883,  716,
      871,  885,  893,  735,  872,  887,  888,  876,  889, 1093,
      890,  869,  870,  875, 1093,  877,  860,  819,  819,  880,
      903,  881,  894,  895,  898,  883,  878,  885,  819,  893,
      904,  887,  888,  879,  889,  819,  890,  869,  870, 1093,
      884,  886, 1093,  825,  825,  892,  892,  903,  894,  895,
      898,  900,  878, 1093,  825, 1093,  892,  904, 1093,  879,
      910,  825,  911,  892,  896,  896,  884,  891,  886,  905,
      897,  897,  906,  899,  899,  896,  907,  900,  908,  902,
      902,  897,  896,  897,  899,  909,  899,  910,  897,  911,

      902,  899,  902,  912,  891,  905,  916,  902,  906,  917,
      473,  914,  907,  915,  908,  913,  913,  701,  858,  920,
      866,  909,  923,  926,  716,  929,  913,  866,  913,  912,
      859,  932,  916,  913, 1093,  917,  473,  701,  914,  934,
      915, 1093,  918,  701,  721,  936,  920,  937,  923,  924,
      926,  929,  866,  875,  866,  875,  716,  735,  932,  716,
      922,  721,  931,  938,  946,  934,  939,  933,  925,  918,
      875,  936,  875,  937,  735,  941,  924,  942,  944, 1093,
      947,  930,  948, 1093,  935, 1093,  922,  940,  940,  931,
      938,  946,  939,  933,  928,  925,  892,  892,  940, 1093,

      940,  941,  949,  942,  944,  940,  947,  892,  930,  948,
      950,  935,  945,  945,  892,  896,  896,  953,  954,  957,
      928,  961,  943,  945,  955,  945,  896, 1093,  949,  960,
      945,  866,  962,  896,  951,  951,  950, 1093,  963, 1093,
     1093, 1093,  964,  953,  954,  951,  957,  952,  961,  943,
      955,  473,  951,  956,  956,  960,  958,  958,  962,  967,
      970,  975,  959,  959,  956,  963,  956,  958,  964,  958,
      866,  956,  969,  959,  958,  959,  977,  473,  966,  974,
      959,  866,  875,  972,  979,  967,  970,  975,  980,  982,
      983, 1093,  984,  985,  986,  986,  974,  988,  969,  875,

     1093,  979,  977,  989,  992,  986,  995,  986,  987,  987,
      996,  981,  986, 1000,  980,  982, 1093,  983,  984,  987,
      985,  987,  976,  988, 1093, 1093,  987,  990,  990,  989,
      992,  993,  993,  995, 1002, 1093,  996,  981,  990, 1000,
      991, 1093,  993, 1003,  993,  990,  994,  994,  976,  993,
      997,  997,  999,  999, 1004, 1005, 1093,  994,  866,  994,
     1002,  997, 1007,  999,  994,  999, 1001, 1001,  997, 1003,
      999,  966,  974,  866,  875,  972,  979, 1001,  866, 1001,
     1004, 1005,  998, 1009, 1001, 1014, 1015, 1016, 1007,  974,
     1017,  875, 1018,  979, 1023, 1019, 1019, 1093, 1011, 1093,

     1025, 1093, 1029, 1013, 1093, 1032, 1019, 1093,  998, 1026,
     1009, 1014, 1015, 1019, 1016, 1020, 1020, 1017, 1018, 1027,
     1028, 1023, 1031, 1024, 1024, 1011, 1020, 1025, 1021, 1029,
     1013,  756, 1032, 1020, 1024, 1026, 1024, 1039,  997,  997,
     1040, 1024, 1034, 1037, 1041, 1027, 1028, 1042, 1031,  997,
     1045,  556,  556, 1046, 1051, 1022,  997,  756, 1093, 1093,
     1037, 1053,  556, 1039,  556, 1093, 1040, 1019, 1019,  556,
      998, 1041, 1043, 1043, 1042, 1020, 1020, 1045, 1019, 1046,
     1051, 1022, 1093, 1043, 1052, 1019, 1020, 1053, 1021, 1062,
     1043, 1047, 1047, 1020, 1048, 1048,  998, 1049, 1049, 1055,

     1056, 1057, 1047,  756, 1047, 1048, 1093, 1048, 1049, 1047,
     1049, 1052, 1048, 1044, 1093, 1049, 1062, 1050, 1050, 1034,
     1037, 1058,  825,  825, 1059, 1055, 1056, 1057, 1050,  756,
     1050, 1043, 1043,  825, 1060, 1050, 1063, 1037, 1093, 1044,
      825, 1061, 1043,  671,  671, 1067, 1068, 1058, 1071, 1043,
     1059,  952,  952, 1074,  671, 1093,  671, 1064, 1064, 1093,
     1060,  671,  952, 1063,  952, 1021, 1021, 1061, 1064,  952,
     1065, 1067, 1044, 1068, 1071, 1064, 1021, 1093, 1021, 1093,
     1074, 1070, 1070, 1021, 1072, 1072, 1078, 1079, 1093, 1080,
     1064, 1064, 1070, 1093, 1070, 1072, 1093, 1066, 1044, 1070,

     1084, 1064, 1072, 1065, 1075, 1075, 1076, 1081, 1064, 1072,
     1072, 1082, 1078, 1079, 1077, 1075, 1080, 1075, 1083, 1083,
     1072, 1085, 1075, 1066, 1093, 1073, 1084, 1072, 1093, 1083,
     1086, 1083, 1076, 1088, 1081, 1089, 1083, 1093, 1082, 1091,
     1077, 1065, 1065, 1093, 1087, 1087, 1093, 1085, 1093, 1093,
     1073, 1073, 1065, 1093, 1065, 1087, 1086, 1087, 1093, 1065,
     1088, 1089, 1087, 1093, 1090, 1090, 1091, 1092, 1092, 1093,
     1093, 1093, 1093, 1093, 1093, 1090, 1073, 1090, 1092, 1093,
     1092, 1093, 1090, 1093, 1093, 1092,   62,   62,   62,   62,
       62,   62,   62,   70,   70,   70,   70,   70,   70,   70,

       82,   82, 1093,   82,  136, 1093,  136,  136,  136,  136,
      136,  158, 1093, 1093,  158,  158, 1093,  158,  168,  168,
      181, 1093,  181,  181,  181,  181,  181,  184, 1093,  184,
      184,  184,  184,  184,  195, 1093,  195,  195,  195,  195,
      195,  198, 1093,  198,  198,  198,  198,  198,  201, 1093,
      201,  201,  201,  201,  201,  203, 1093,  203,  203,  203,
      203,  203,  230, 1093,  230,  230,  230,  230,  230,  233,
     1093,  233,  233,  233,  233,  233,  235, 1093,  235,  235,
      235,  235,  235,  237, 1093,  237,  237,  237,  237,  237,
      288, 1093,  288,  288,  288,  288,  288,  290, 1093,  290,

      290,  290,  290,  290,  307, 1093,  307,  307,  307,  307,
      307,  309, 1093,  309,  309,  309,  309,  309,  325, 1093,
      325,  325,  325,  325,  325,  327, 1093,  327,  327,  327,
      327,  327,  523,  523,  523,  523,  523,  523,  523,  537,
      537,  537,  537,  537,  537,  537,  538,  538,  538,  538,
      538,  538,  538,  690, 1093,  690,  698,  698,  698,  698,
      698,  698,  698,  700,  700,  700,  700,  700,  700,  700,
      705,  705,  705,  705,  705,  705,  705,  707,  707,  707,
      707,  707,  707,  707,  709, 1093,  709,  709,  709,  709,
      709,  715,  715,  715,  715,  715,  715,  715,  718,  718,

      718,  718,  718,  718,  718,  720,  720,  720,  720,  720,
      720,  720,  725,  725,  725,  725,  725,  725,  725,  727,
      727,  727,  727,  727,  727,  727,  734,  734,  734,  734,
      734,  734,  734,  719,  719,  719,  719,  719,  719,  719,
      721,  721,  721,  721,  721,  721,  721,  726,  726,  726,
      726,  726,  726,  726,  728,  728,  728,  728,  728,  728,
      728,  735,  735,  735,  735,  735,  735,  735,  794,  794,
      794,  794,  794,  794,  794,  804,  804,  804,  804,  804,
      804,  804,  805,  805,  805,  805,  805,  805,  805,  865,
      865,  865,  865,  865,  865,  865,  874,  874,  874,  874,

      874,  874,  874,  875,  875,  875,  875,  875,  875,  875,
      965,  965,  965,  965,  965,  965,  965,  971,  971,  971,
      971,  971,  971,  971,  973,  973,  973,  973,  973,  973,
      973,  978,  978,  978,  978,  978,  978,  978,  974,  974,
      974,  974,  974,  974,  974,  979,  979,  979,  979,  979,
      979,  979, 1033, 1033, 1033, 1033, 1033, 1033, 1033, 1036,
     1036, 1036, 1036, 1036, 1036, 1036, 1037, 1037, 1037, 1037,
     1037, 1037, 1037,   11, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,

     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093
    } ;

static const flex_int16_t yy_chk[3551] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    2,    2, 1108,    2,
        3,    3,    3,    3, 1103,    3,    3,    4,    4, 1061,
        4,   16,   16,   21,   21,    7,    7,    4,    4,    4,

        4,   33,    4,    4,    5,    5,    5,   22,   22,    5,
        5,    6,    6,    7,    6,    8,    8,   36,    8,   23,
       23,    6,    6,    6,   65,    7,    6,    6,   28,   28,
     1038,   25,   23,    8,   25,   25,   51,   33,   51,   53,
     1037,   53,   53, 1035,   36,    8,   55, 1033,   55,   55,
       65, 1013,    7,   36,   32,   32,   37,   37,   32,   66,
       37,   66, 1009,   38,   32, 1005,   37,   25,   75,   75,
       36,   35,    8,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,   38,    9,    9,   31,
       42,    9,    9,    9,    9,    9,   45,   32,   35,   38,

       32,   35,   37,  982,   31,   43,   80,   35,   42,  980,
       31,   58,   38,   45,  979,   58,   58,  977,   31,   43,
       77,   77,    9,   32,   35,   31,   42,   35,  975,   82,
       41,   31,   45,   48,   48,   42,   31,   48,  974,   41,
       45,   43,   80,   48,   31,   72,   43,   72,    9,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   41,   10,   10,   82,   34,   10,   10,   10,
       10,   10,   94,   49,   46,   41,   39,   49,   46,   48,
       39,   91,   91,   49,   46,   94,   39,  971,   41,   34,
       60,  970,   34,   47,   60,   60,  967,   34,   10,   34,

       39,  134,   34,   81,   39,  965,   81,   81,   94,   46,
       47,   47,   94,   78,   78,   34,  963,   46,   34,   49,
       46,  142,   39,   34,   10,   34,   78,   39,  134,   47,
      935,   39,   40,   56,   56,   46,   40,   47,   47,   81,
       59,   87,   40,   46,   59,   59,   56,  142,   56,   56,
      931,   88,   79,   79,   40,   59,   40,   57,   57,   56,
       57,   57,  138,   61,   61,   79,   40,   61,   61,   95,
       87,  114,  114,   89,   89,   40,   96,   87,   40,   98,
       88,   40,   59,   40,   89,   89,   56,   88,   99,  138,
       96,   89,   40,   57,   93,  104,   87,   97,   93,   95,

       61,   40,   44,   98,   93,   95,   88,  927,  100,   97,
      924,   99,   96,  921,   44,   98,   44,   96,  111,  108,
       44,   89,  100,  153,   99,   95,  104,  153,  153,   98,
      119,  104,   44,   97,   44,  110,   97,   99,   44,  110,
       93,   44,  108,   44,  100,  110,  113,   44,  107,  100,
      113,  111,  104,  119,  111,  108,  113,  116,   44,  139,
       44,   52,  918,   52,   52,  880,  119,  140,  108,  116,
      875,  107,   52,   52,   52,   52,  107,  111,   52,  119,
       52,  110,  120,  607,  107,  873,  139,  871,   52,  121,
       52,   52,  113,  116,  140,  607,  116,  107,   52,   52,

       52,   52,  107,  865,   52,  864,   52,   67,  125,   67,
       67,  115,  115,  123,  121,  183,  183,  120,  120,   67,
       67,   67,  115,  115,   67,  121,   67,  123,  861,  115,
      112,  112,  125,  118,   67,  141,   67,   67,  839,  122,
      121,  112,  112,  120,  125,   67,   67,   67,  112,  123,
       67,  117,   67,   73,  123,   73,   73,  122,  125,  115,
      118,  117,  141,  127,  126,   73,   73,   73,  126,  118,
       73,  112,   73,  128,  126,  122,  143,  127,  112,  117,
       73,  144,   73,   73,  122,  145,  118,  117,  117,  214,
      214,   73,   73,   73,  143,  814,   73,  112,   73,  127,

      137,  807,  128,  143,  127,  117,  146,  146,  144,  128,
      126,  145,  149,  149,  137,  137,  147,  146,  147,  147,
      143,  151,  151,  149,  151,  151,  164,  137,  128,  150,
      167,  150,  150,  805,  150,  150,  152,  152,  155,  155,
      137,  137,  161,  162,  146,  163,  166,  152,  160,  155,
      149,  170,  164,  156,  156,  156,  167,  151,  156,  156,
      157,  157,  160,  160,  157,  157,  165,  169,  171,  161,
      162,  172,  163,  166,  152,  160,  155,  173,  170,  175,
      618,  169,  169,  176,  165,  178,  174,  177,  160,  160,
      177,  177,  618,  165,  169,  171,  803,  157,  172,  178,

      179,  180,  180,  173,  174,  797,  175,  169,  169,  176,
      165,  190,  180,  174,  179,  794,  192,  188,  188,  180,
      206,  178,  189,  177,  180,  191,  178,  180,  188,  188,
      174,  193,  189,  209,  190,  188,  179,  205,  192,  191,
      194,  179,  180,  193,  240,  200,  239,  190,  206,  207,
      194,  180,  192,  205,  180,  200,  206,  216,  189,  189,
      190,  191,  209,  207,  192,  188,  191,  193,  180,  209,
      193,  240,  239,  205,  206,  241,  194,  194,  210,  210,
      205,  200,  200,  211,  211,  207,  216,  224,  209,  210,
      207,  242,  243,  216,  211,  211,  210,  632,  217,  218,

      210,  211,  241,  210,  793,  219,  221,  749,  220,  632,
      224,  217,  216,  218,  253,  253,  223,  242,  243,  219,
      221,  220,  739,  224,  222,  258,  258,  210,  225,  244,
      210,  211,  215,  215,  217,  218,  224,  229,  217,  245,
      218,  219,  221,  215,  220,  223,  219,  221,  220,  222,
      215,  225,  223,  228,  229,  247,  244,  246,  215,  249,
      222,  248,  251,  250,  225,  245,  735,  215,  215,  728,
      250,  223,  215,  229,  257,  222,  228,  225,  257,  257,
      726,  229,  247,  246,  263,  215,  249,  248,  251,  228,
      250,  721,  261,  215,  215,  262,  250,  252,  215,  252,

      252,  254,  228,  254,  254,  255,  255,  259,  255,  255,
      263,  259,  259,  260,  260,  719,  264,  260,  260,  261,
      265,  267,  262,  266,  715,  268,  269,  270,  710,  271,
      272,  273,  707,  274,  270,  275,  276,  705,  277,  278,
      280,  255,  264,  279,  282,  281,  283,  265,  267,  266,
      260,  268,  281,  269,  270,  271,  284,  272,  273,  274,
      270,  275,  285,  276,  277,  287,  278,  280,  293,  279,
      282,  295,  281,  283,  286,  286,  292,  292,  281,  313,
      700,  294,  283,  284,  304,  305,  698,  292,  285,  293,
      297,  287,  284,  299,  292,  697,  295,  311,  298,  283,

      286,  286,  311,  292,  293,  313,  300,  295,  641,  284,
      294,  304,  305,  292,  299,  293,  312,  294,  636,  297,
      296,  296,  295,  311,  345,  345,  297,  298,  311,  299,
      292,  296,  296,  635,  298,  300,  294,  315,  296,  292,
      299,  316,  300,  312,  314,  297,  301,  301,  302,  302,
      317,  303,  303,  298,  331,  321,  318,  301,  301,  302,
      302,  300,  303,  303,  301,  634,  302,  315,  296,  303,
      318,  314,  335,  315,  631,  316,  629,  316,  336,  317,
      622,  331,  321,  617,  333,  611,  317,  610,  302,  346,
      346,  321,  318,  315,  301,  334,  302,  318,  335,  303,

      322,  316,  332,  332,  336,  317,  319,  319,  321,  320,
      320,  333,  322,  337,  302,  306,  306,  319,  319,  319,
      320,  320,  334,  338,  319,  609,  306,  320,  332,  332,
      339,  323,  323,  306,  340,  341,  322,  306,  606,  322,
      337,  306,  323,  323,  342,  306,  538,  324,  324,  323,
      338,  306,  343,  654,  319,  306,  339,  320,  324,  324,
      340,  341,  329,  329,  306,  324,  344,  523,  306,  348,
      342,  349,  306,  329,  329,  329,  350,  306,  343,  323,
      329,  306,  330,  330,  508,  347,  347,  351,  352,  654,
      353,  354,  344,  330,  330,  324,  348,  355,  349,  356,

      330,  357,  350,  358,  455,  359,  359,  360,  361,  364,
      329,  347,  347,  351,  362,  352,  353,  354,  363,  365,
      366,  367,  368,  355,  369,  356,  370,  357,  372,  358,
      330,  359,  359,  373,  360,  361,  364,  375,  374,  429,
      362,  376,  371,  371,  363,  365,  366,  367,  368,  377,
      369,  372,  370,  371,  371,  378,  381,  327,  391,  373,
      371,  379,  379,  375,  372,  374,  384,  376,  515,  515,
      383,  325,  379,  379,  309,  377,  307,  372,  385,  379,
      384,  378,  380,  380,  391,  381,  382,  382,  383,  397,
      371,  290,  381,  380,  380,  386,  385,  382,  392,  393,

      380,  379,  384,  395,  382,  288,  383,  384,  400,  379,
      382,  381,  386,  256,  385,  383,  397,  387,  387,  398,
      399,  237,  401,  385,  392,  393,  642,  379,  387,  395,
      380,  386,  388,  388,  400,  387,  235,  382,  642,  386,
      396,  390,  390,  388,  389,  389,  398,  399,  396,  401,
      388,  402,  390,  387,  233,  389,  389,  416,  387,  390,
      230,  403,  389,  394,  394,  388,  396,  227,  394,  390,
      704,  704,  406,  394,  396,  404,  404,  402,  390,  387,
      415,  410,  418,  416,  387,  226,  404,  404,  403,  394,
      394,  388,  389,  404,  394,  406,  390,  403,  410,  394,

      405,  405,  408,  408,  390,  409,  417,  415,  406,  418,
      419,  405,  405,  408,  403,  411,  411,  410,  405,  409,
      408,  406,  420,  404,  421,  410,  411,  423,  408,  422,
      724,  724,  417,  411,  412,  412,  424,  419,  432,  414,
      414,  409,  425,  422,  422,  412,  409,  426,  405,  420,
      414,  421,  412,  423,  411,  408,  412,  414,  412,  433,
      412,  213,  427,  424,  414,  432,  428,  430,  425,  431,
      434,  435,  437,  426,  414,  436,  438,  439,  440,  441,
      411,  212,  443,  412,  444,  412,  433,  412,  427,  442,
      442,  414,  428,  430,  445,  431,  446,  434,  435,  437,

      414,  436,  438,  439,  440,  441,  447,  442,  443,  448,
      444,  449,  450,  203,  451,  452,  453,  454,  458,  457,
      516,  445,  462,  446,  201,  463,  468,  456,  456,  457,
     1010, 1010,  198,  447,  516,  516,  448,  449,  456,  450,
      451,  452,  453,  454,  458,  456,  459,  459,  462,  460,
      460,  463,  468,  456,  467,  457,  457,  459,  459,  459,
      460,  469,  460,  195,  459,  461,  461,  460,  464,  464,
      465,  465,  467,  466,  466,  473,  461,  474,  461,  464,
      456,  465,  465,  461,  466,  469,  464,  470,  465,  471,
      467,  466,  475,  478,  472,  472,  477,  469,  483,  467,

      479,  473,  471,  480,  474,  472,  472,  482,  187,  464,
      486,  469,  472,  466,  470,  476,  476,  186,  465,  475,
      478,  484,  477,  470,  483,  471,  476,  479,  485,  471,
      480,  488,  490,  476,  482,  464,  486,  476,  476,  466,
      470,  491,  472,  481,  481,  489,  492,  493,  484,  487,
      487,  494,  495,  499,  481,  485,  476,  184,  488,  490,
      487,  481,  500,  503,  476,  476,  495,  487,  491,  496,
      496,  489,  492,  493,  497,  497,  502,  506,  494,  499,
      496,  504,  476,  498,  498,  497,  501,  496,  495,  503,
      500,  505,  497,  495,  498,  498,  507,  501,  500,  509,

      510,  498,  511,  502,  506,  181,  512,  504,  513,  154,
      496,  514,  517,  518,  148,  497,  500,  505,  519,  520,
      521,  522,  507,  525,  526,  509,  510,  527,  529,  511,
      528,  498,  512,  501,  530,  513,  496,  514,  517,  531,
      518,  497,  532,  533,  534,  519,  520,  521,  522,  525,
      526,  535,  536,  541,  527,  529,  528,  537,  537,  539,
      530,  540,  542,  543,  546,  531,  544,  545,  547,  532,
      533,  534,  548,  549,  550,  537,  551,  552,  535,  536,
      541,  553,  555,  558,  559,  539,  560,  540,  542,  561,
      543,  546,  544,  545,  562,  547,  563,  551,  564,  548,

      549,  550,  569,  551,  790,  570,  552,  553,  555,  133,
      558,  559,  560,  552,  132,  561,  790,  571,  562,  131,
      572,  564,  563,  551,  565,  565,  573,  566,  566,  569,
      562,  570,  552,  575,  564,  565,  565,  574,  566,  566,
      567,  567,  565,  571,  562,  566,  572,  564,  568,  568,
      581,  567,  573,  576,  585,  129,  577,  577,  567,  568,
      575,  798,  582,  574,  583,  586,  568,  577,  106,  577,
      578,  578,  565,  798,  577,  566,  567,  581,  590,  576,
      585,  578,  579,  579,  587,  588,  580,  580,  578,  582,
      593,  583,  586,  579,  579,  579,  578,  580,  600,  580,

      579,  594,  567,  815,  580,  590,  584,  584,  589,  589,
      587,  588,  105,  596,  103,  815,  593,  584,  101,  589,
      591,  591,  597,  578,  584,  600,  589,  594,  599,  592,
      592,  591,  584,  595,  595,  601,   92,  605,  591,  596,
      592,  592,  584,  602,  595,  603,  584,  592,  598,  613,
      597,  595,  608,  614,  599,  604,  604,  595,  597,  584,
      615,  601,  598,  598,  605,  616,  604,  621,  584,  602,
      625,  603,  584,  604,  626,  613,  597,  592,  627,  608,
      614,  619,  619,  628,  595,  620,  620,  615,  623,  623,
      624,  624,  616,  633,  621,  637,  625,  620,  638,  619,

      639,  626,   90,  620,  640,  627,  623,  644,  624,  646,
      628,  630,  630,  647,  651,  643,  643,  648,  645,  649,
      633,  637,  657,  630,  652,  638,  643,  639,  643,  630,
       83,  640,  645,  643,  644,  646,  660,  650,  650,  659,
      647,  651,  662,  648,   74,  649,  663,  652,  650,  657,
      650,  653,  653,  665,  645,  650,  655,  655,  664,  645,
      652,  670,  653,  660,  653,  659,   71,  655,  662,  653,
      656,  656,  663,  652,  655,  661,  661,  672,  658,  658,
      665,  656,  666,  677,  664,  673,  661,  670,  656,  658,
      668,  668,  655,  661,  674,  675,  658,  655,  676,   69,

      675,  680,  656,  672,  658,   64,  679,   63,  682,  666,
      677,  673,  684,   54,  678,  678,  668,  668,  655,  686,
      674,  675,  685,  655,  676,  678,  675,  680,  656,  681,
      681,  658,  678,  679,  682,  683,  683,  687,  691,  684,
      681,  702,   50,  688,  688,  686,  683,  681,   30,  685,
      717,  692,  694,  683,  688,  688,  688,  693,  689,  689,
      695,  688,   27,  687,  691,   20,  681,  690,  690,  689,
      703,  689,  714,  689,  689,  683,  689,  692,  690,  694,
      690,  702,  711,  693,  712,  690,  713,  695,  696,  696,
      717,  688,  681,  737,  718,  718,  723,  703,  714,  696,

      730,  683,  720,  720,  722,  722,  696,  702,  733,  711,
      696,  712,  718,  713,  725,  725,  717,  727,  727,  731,
      720,  732,  722,  723,  729,  729,  738,  730,  740,  734,
      734,  741,  725,  737,  733,  727,  742,  696,  736,  736,
      743,  744,  729,   14,  722,  746,  731,  734,  732,  747,
      747,  748,  748,  738,  753,  740,  736,  750,  741,  737,
      747,  747,  748,  742,  748,  751,  743,  747,  756,  748,
      722,  757,  746,  758,   11,  754,  754,  760,  736,  762,
      753,  744,    0,  768,  750,    0,  754,  754,  759,  759,
      764,  766,  751,  754,  756, 1012, 1012,  747,  757,  759,

      758,  759,  771,  760,  736,  762,  759,  744,  761,  761,
      768,  763,  763,  769,  765,  765,  764,  766,  770,  761,
      772,  761,  763,  754,  773,  765,  761,  765,  771,  763,
      767,  767,  765,  776,  763,    0,  777,  778,  774,  774,
      769,  767,  779,  767,  780,  770,  785,  772,  767,  774,
      773,  781,  763,  782,  775,  775,  774,  786,  787,  791,
      776,  763,  777,  778,  774,  775,  788,  775,  792,  779,
      796,  780,  775,  785,  799,  789,  789,  781,  763,  782,
      800,  801,  801,  786,  802,  787,  789,  806,  789,  804,
      804,  774,  788,  789,  792,  810,  810,  796,  809,  801,

      791,  799,  811,  812,  813,  808,  808,  804,  816,  817,
      802,  818,  827,  810,  806,  821,  822,  808,  823,    0,
      824,  800,  801,  808,    0,  809,  791,  819,  819,  812,
      841,  813,  828,  830,  834,  816,  810,  818,  819,  827,
      842,  821,  822,  811,  823,  819,  824,  800,  801,    0,
      817,  819,    0,  825,  825,  826,  826,  841,  828,  830,
      834,  838,  810,    0,  825,    0,  826,  842,    0,  811,
      849,  825,  850,  826,  831,  831,  817,  825,  819,  843,
      833,  833,  844,  836,  836,  831,  846,  838,  847,  840,
      840,  833,  831,  833,  836,  848,  836,  849,  833,  850,

      840,  836,  840,  851,  825,  843,  855,  840,  844,  856,
      831,  853,  846,  854,  847,  852,  852,  860,  858,  863,
      867,  848,  868,  872,  869,  877,  852,  882,  852,  851,
      858,  881,  855,  852,    0,  856,  831,  879,  853,  883,
      854,    0,  860,  870,  870,  885,  863,  886,  868,  869,
      872,  877,  874,  874,  876,  876,  878,  878,  881,  884,
      867,  870,  879,  887,  895,  883,  888,  882,  870,  860,
      874,  885,  876,  886,  878,  890,  869,  891,  893,    0,
      898,  878,  900,    0,  884,    0,  867,  889,  889,  879,
      887,  895,  888,  882,  876,  870,  892,  892,  889,    0,

      889,  890,  901,  891,  893,  889,  898,  892,  878,  900,
      903,  884,  894,  894,  892,  896,  896,  905,  906,  909,
      876,  914,  892,  894,  907,  894,  896,    0,  901,  912,
      894,  922,  915,  896,  904,  904,  903,    0,  916,    0,
        0,    0,  917,  905,  906,  904,  909,  904,  914,  892,
      907,  896,  904,  908,  908,  912,  910,  910,  915,  920,
      923,  926,  911,  911,  908,  916,  908,  910,  917,  910,
      933,  908,  922,  911,  910,  911,  929,  896,  925,  925,
      911,  928,  928,  930,  930,  920,  923,  926,  932,  934,
      936,    0,  937,  938,  939,  939,  925,  942,  922,  928,

        0,  930,  929,  943,  946,  939,  949,  939,  941,  941,
      950,  933,  939,  954,  932,  934,    0,  936,  937,  941,
      938,  941,  928,  942,    0,    0,  941,  944,  944,  943,
      946,  947,  947,  949,  957,    0,  950,  933,  944,  954,
      944,    0,  947,  960,  947,  944,  948,  948,  928,  947,
      951,  951,  953,  953,  961,  962,    0,  948,  969,  948,
      957,  951,  964,  953,  948,  953,  955,  955,  951,  960,
      953,  973,  973,  976,  976,  978,  978,  955,  981,  955,
      961,  962,  951,  969,  955,  983,  984,  985,  964,  973,
      988,  976,  989,  978,  995,  990,  990,    0,  976,    0,

      998,    0, 1004,  981,    0, 1007,  990,    0,  951, 1000,
      969,  983,  984,  990,  985,  992,  992,  988,  989, 1002,
     1003,  995, 1006,  996,  996,  976,  992,  998,  992, 1004,
      981,  990, 1007,  992,  996, 1000,  996, 1014,  997,  997,
     1015,  996, 1011, 1011, 1017, 1002, 1003, 1018, 1006,  997,
     1023, 1016, 1016, 1025, 1030,  992,  997,  990,    0,    0,
     1011, 1032, 1016, 1014, 1016,    0, 1015, 1019, 1019, 1016,
      997, 1017, 1020, 1020, 1018, 1022, 1022, 1023, 1019, 1025,
     1030,  992,    0, 1020, 1031, 1019, 1022, 1032, 1022, 1055,
     1020, 1026, 1026, 1022, 1027, 1027,  997, 1028, 1028, 1040,

     1041, 1042, 1026, 1019, 1026, 1027,    0, 1027, 1028, 1026,
     1028, 1031, 1027, 1020,    0, 1028, 1055, 1029, 1029, 1036,
     1036, 1044, 1039, 1039, 1051, 1040, 1041, 1042, 1029, 1019,
     1029, 1043, 1043, 1039, 1052, 1029, 1056, 1036,    0, 1020,
     1039, 1053, 1043, 1045, 1045, 1059, 1060, 1044, 1063, 1043,
     1051, 1046, 1046, 1067, 1045,    0, 1045, 1057, 1057,    0,
     1052, 1045, 1046, 1056, 1046, 1058, 1058, 1053, 1057, 1046,
     1057, 1059, 1043, 1060, 1063, 1057, 1058,    0, 1058,    0,
     1067, 1062, 1062, 1058, 1064, 1064, 1071, 1073,    0, 1074,
     1066, 1066, 1062,    0, 1062, 1064,    0, 1057, 1043, 1062,

     1080, 1066, 1064, 1066, 1068, 1068, 1069, 1076, 1066, 1072,
     1072, 1077, 1071, 1073, 1069, 1068, 1074, 1068, 1078, 1078,
     1072, 1081, 1068, 1057,    0, 1064, 1080, 1072,    0, 1078,
     1082, 1078, 1069, 1085, 1076, 1086, 1078,    0, 1077, 1089,
     1069, 1079, 1079,    0, 1084, 1084,    0, 1081,    0,    0,
     1072, 1064, 1079,    0, 1079, 1084, 1082, 1084,    0, 1079,
     1085, 1086, 1084,    0, 1088, 1088, 1089, 1091, 1091,    0,
        0,    0,    0,    0,    0, 1088, 1072, 1088, 1091,    0,
     1091,    0, 1088,    0,    0, 1091, 1094, 1094, 1094, 1094,
     1094, 1094, 1094, 1095, 1095, 1095, 1095, 1095, 1095, 1095,

     1096, 1096,    0, 1096, 1097,    0, 1097, 1097, 1097, 1097,
     1097, 1098,    0,    0, 1098, 1098,    0, 1098, 1099, 1099,
     1100,    0, 1100, 1100, 1100, 1100, 1100, 1101,    0, 1101,
     1101, 1101, 1101, 1101, 1102,    0, 1102, 1102, 1102, 1102,
     1102, 1104,    0, 1104, 1104, 1104, 1104, 1104, 1105,    0,
     1105, 1105, 1105, 1105, 1105, 1106,    0, 1106, 1106, 1106,
     1106, 1106, 1107,    0, 1107, 1107, 1107, 1107, 1107, 1109,
        0, 1109, 1109, 1109, 1109, 1109, 1110,    0, 1110, 1110,
     1110, 1110, 1110, 1111,    0, 1111, 1111, 1111, 1111, 1111,
     1112,    0, 1112, 1112, 1112, 1112, 1112, 1113,    0, 1113,

     1113, 1113, 1113, 1113, 1114,    0, 1114, 1114, 1114, 1114,
     1114, 1115,    0, 1115, 1115, 1115, 1115, 1115, 1116,    0,
     1116, 1116, 1116, 1116, 1116, 1117,    0, 1117, 1117, 1117,
     1117, 1117, 1118, 1118, 1118, 1118, 1118, 1118, 1118, 1119,
     1119, 1119, 1119, 1119, 1119, 1119, 1120, 1120, 1120, 1120,
     1120, 1120, 1120, 1121,    0, 1121, 1122, 1122, 1122, 1122,
     1122, 1122, 1122, 1123, 1123, 1123, 1123, 1123, 1123, 1123,
     1124, 1124, 1124, 1124, 1124, 1124, 1124, 1125, 1125, 1125,
     1125, 1125, 1125, 1125, 1126,    0, 1126, 1126, 1126, 1126,
     1126, 1127, 1127, 1127, 1127, 1127, 1127, 1127, 1128, 1128,

     1128, 1128, 1128, 1128, 1128, 1129, 1129, 1129, 1129, 1129,
     1129, 1129, 1130, 1130, 1130, 1130, 1130, 1130, 1130, 1131,
     1131, 1131, 1131, 1131, 1131, 1131, 1132, 1132, 1132, 1132,
     1132, 1132, 1132, 1133, 1133, 1133, 1133, 1133, 1133, 1133,
     1134, 1134, 1134, 1134, 1134, 1134, 1134, 1135, 1135, 1135,
     1135, 1135, 1135, 1135, 1136, 1136, 1136, 1136, 1136, 1136,
     1136, 1137, 1137, 1137, 1137, 1137, 1137, 1137, 1138, 1138,
     1138, 1138, 1138, 1138, 1138, 1139, 1139, 1139, 1139, 1139,
     1139, 1139, 1140, 1140, 1140, 1140, 1140, 1140, 1140, 1141,
     1141, 1141, 1141, 1141, 1141, 1141, 1142, 1142, 1142, 1142,

     1142, 1142, 1142, 1143, 1143, 1143, 1143, 1143, 1143, 1143,
     1144, 1144, 1144, 1144, 1144, 1144, 1144, 1145, 1145, 1145,
     1145, 1145, 1145, 1145, 1146, 1146, 1146, 1146, 1146, 1146,
     1146, 1147, 1147, 1147, 1147, 1147, 1147, 1147, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1149, 1149, 1149, 1149, 1149,
     1149, 1149, 1150, 1150, 1150, 1150, 1150, 1150, 1150, 1151,
     1151, 1151, 1151, 1151, 1151, 1151, 1152, 1152, 1152, 1152,
     1152, 1152, 1152, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,

     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093,
     1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093, 1093
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "../../cobc/scanner.l"
/*
   Copyright (C) 2001-2012, 2014-2022 Free Software Foundation, Inc.
   Written by Keisuke Nishida, Roger While, Simon Sobisch, Edwart Hart,
   Ron Norman

   This file is part of GnuCOBOL.

   The GnuCOBOL compiler is free software: you can redistribute it
   and/or modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation, either version 3 of the
   License, or (at your option) any later version.

   GnuCOBOL is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with GnuCOBOL.  If not, see <https://www.gnu.org/licenses/>.
*/
#line 49 "../../cobc/scanner.l"

#undef	YY_READ_BUF_SIZE
#define	YY_READ_BUF_SIZE	32768
#undef	YY_BUF_SIZE
#define	YY_BUF_SIZE		32768

#define	YY_SKIP_YYWRAP
static int yywrap (void) {
    return 1;
}

#define YY_INPUT(buf,result,max_size)				\
	{							\
		if (fgets (buf, (int)max_size, yyin) == NULL) { \
			result = YY_NULL;			\
		} else {					\
			result = strlen (buf);			\
		}						\
	}

#define	YY_USER_INIT						\
	if (!plex_buff) {					\
		plex_size = COB_MINI_BUFF;			\
		plex_buff = cobc_malloc (plex_size);		\
	}							\
	if (!pic_buff1) {					\
		pic1_size = COB_MINI_BUFF;			\
		pic_buff1 = cobc_malloc (pic1_size);		\
	}							\
	if (!pic_buff2) {					\
		pic2_size = COB_MINI_BUFF;			\
		pic_buff2 = cobc_malloc (pic2_size);		\
	}

#include "config.h"

#include <ctype.h>
#include <limits.h>

#include <string.h>
#ifdef	HAVE_STRINGS_H
#include <strings.h>
#endif

#ifdef	HAVE_UNISTD_H
#include <unistd.h>
#else
#define	YY_NO_UNISTD_H	1
#endif

#define	COB_IN_SCANNER	1
#include "cobc.h"
#include "tree.h"

/* ignore unused functions here as flex generates unused ones */
#ifdef	__GNUC__
#if	defined (__clang__) || __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 4)
#pragma GCC diagnostic ignored "-Wunused-function"
#endif
#endif

#define YYSTYPE			cb_tree
#define _PARSER_H	/* work around bad Windows SDK header */
#include "parser.h"

#define RETURN_TOK(expr)			\
	do {					\
		last_yylval = yylval;		\
		last_token = (expr);		\
		return last_token;		\
	} ONCE_COB

#define SET_LOCATION(x)                         \
	do {					\
		(x)->source_file = cb_source_file;		\
		(x)->source_line = cb_source_line;		\
	} ONCE_COB

/* CONSTANT (78 level) structure */
struct cb_level_78 {
	struct cb_level_78	*next;		/* Next in chain */
	struct cb_level_78	*glob_next;	/* Continued next in chain */
	struct cb_level_78	*last;		/* Last in chain */
	struct cb_field		*fld_78;		/* Pointer to field */
	struct cb_program	*prog;		/* Program where defined */
	cob_u32_t		name_len;	/* Length of name */
	cob_u32_t		not_const;	/* Invalid usage check */
	cob_u32_t		chk_const;	/* Check global level use */
};

struct cb_top_level_78 {
	struct cb_top_level_78	*next;
	struct cb_level_78	*lev_78_ptr;
};

/* Local variables */
static cb_tree			last_yylval;
static int			last_token;
static struct cb_level_78	*top_78_ptr = NULL;
static struct cb_level_78	*const_78_ptr = NULL;
static struct cb_level_78	*lev_78_ptr = NULL;
static struct cb_level_78	*glob_lev_78_ptr = NULL;
static char			*plex_buff = NULL;
static char			*pic_buff1 = NULL;
static char			*pic_buff2 = NULL;
static size_t			plex_size;
static size_t			pic1_size;
static size_t			pic2_size;
static unsigned int		last_token_is_dot = 0;
static unsigned int		integer_is_label = 0;
static unsigned int		inside_bracket = 0;
static char			err_msg[COB_MINI_BUFF];

/* Function declarations */
static void	read_literal (const char, const char *);
static int	scan_x (const char *, const char *);
static int	scan_z (const char *, const char *);
static int	scan_h (const char *, const char *);
static int	scan_b (const char *, const char *);
static int	scan_o (const char *, const char *);
static int	scan_numeric (const char *);
static int	scan_floating_numeric (const char *);
static void	scan_picture (const char *);
static void	count_lines (const char *);
static void	scan_define_options (const char *);
static void	copy_word_in_quotes (char ** const);
static void	copy_two_words_in_quotes (char ** const, char ** const);
static void	add_synonym (const int, const int);
static void	make_synonym (void);
static void clear_constants (void);

#line 1751 "scanner.c"

#line 1753 "scanner.c"

#define INITIAL 0
#define DECIMAL_IS_PERIOD 1
#define DECIMAL_IS_COMMA 2
#define PICTURE_STATE 3
#define FUNCTION_STATE 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 187 "../../cobc/scanner.l"



#line 191 "../../cobc/scanner.l"
	if (likely (current_program)) {
		if (current_program->decimal_point == '.') {
			BEGIN DECIMAL_IS_PERIOD;
		} else {
			BEGIN DECIMAL_IS_COMMA;
		}
	}

	if (cobc_repeat_last_token) {
		cobc_repeat_last_token = 0;
		yylval = last_yylval;
	        return last_token;
	}

	/* We treat integer literals immediately after '.' as labels;
	   that is, they must be level numbers or section names. */
	if (last_token_is_dot) {
		integer_is_label = 1;
		last_token_is_dot = 0;
	} else {
		integer_is_label = 0;
	}
	cobc_in_area_a = 0;


#line 1983 "scanner.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1094 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 1093 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 216 "../../cobc/scanner.l"
{
	if (current_program) {
		const char	*p1;
		char		*p2;
		if (current_program->extfh) {
			cobc_parse_free ((void *)current_program->extfh);
			current_program->extfh = NULL;
		}
		p1 = strchr (yytext, '"');
		if (p1) {
			++p1;
			p2 = strrchr (p1, '"');
			if (p2) {
				*p2 = 0;
				if (strcmp (p1, "EXTFH")) {
					current_program->extfh = cobc_parse_strdup (p1);
				}
			}
		}
	}
}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 239 "../../cobc/scanner.l"
{
	scan_define_options (yytext);
}
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 243 "../../cobc/scanner.l"
{
	char	*word;

	copy_word_in_quotes (&word);
	add_reserved_word_now (word, NULL);
	cobc_free (word);
}
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 251 "../../cobc/scanner.l"
{
	add_synonym (1, 0);
}
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 254 "../../cobc/scanner.l"
{
	add_synonym (0, 0);
}
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 258 "../../cobc/scanner.l"
{
	make_synonym ();
 }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 262 "../../cobc/scanner.l"
{
	add_synonym (1, 1);
}
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 265 "../../cobc/scanner.l"
{
	add_synonym (0, 1);
}
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 269 "../../cobc/scanner.l"
{
	char	*word;

	copy_word_in_quotes (&word);
	if (!is_reserved_word (word)) {
		cb_error (_("'%s' is not a reserved word, so cannot be removed"),
			word);
	} else {
		remove_reserved_word_now (word);
	}
	cobc_free (word);
}
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 282 "../../cobc/scanner.l"
{
	char	*word;

	copy_word_in_quotes (&word);
	remove_reserved_word_now (word);
	cobc_free (word);
}
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 290 "../../cobc/scanner.l"
{
	cb_ref_mod_zero_length = (yytext[13] - '0');
}
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 294 "../../cobc/scanner.l"
{
	cb_odoslide = (yytext[10] - '0');
}
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 298 "../../cobc/scanner.l"
{
	cb_assign_type_default = (enum cb_assign_type)(yytext[8] - '0');
}
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 302 "../../cobc/scanner.l"
{
	struct cb_turn_list	*l;

	for (l = cb_turn_list; l && l->line != -1; l = l->next);
	if (l) {
		l->line = cb_source_line;
	}
}
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 311 "../../cobc/scanner.l"
{
	cobc_areacheck = 1;
}
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 315 "../../cobc/scanner.l"
{
	cobc_areacheck = 0;
}
	YY_BREAK
case 17:
/* rule 17 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 319 "../../cobc/scanner.l"
{
	count_lines (yytext + 9); /* skip "\n#area_a\n" */
	if (cobc_in_procedure && cobc_areacheck) {
		(void) cb_syntax_check (_("separator period in Area A"));
	}
}
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 326 "../../cobc/scanner.l"
{
	cobc_in_area_a = 1;
}
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 330 "../../cobc/scanner.l"
{
	cb_source_line++;
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 334 "../../cobc/scanner.l"
{
	/* Line directive */
	char		*p1;
	char		*p2;

	p1 = strchr (yytext, '"');
	if (p1) {
		p2 = p1 + 1;
		p1 = strrchr (p2, '"');
		if (p1) {
			*p1 = 0;
			cb_source_file = cobc_parse_strdup (p2);
			/* FIXME: only place where strol is used, replace by cobc internal
			          function for base 10 (found in cobc.c already) and base 16,
			          remove from configure.ac */
			cb_source_line = (int)strtol (yytext + 5, NULL, 10) - 1;
		}
	}
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 354 "../../cobc/scanner.l"
{
	/* Ignore */
}
	YY_BREAK
case 22:
#line 359 "../../cobc/scanner.l"
case 23:
YY_RULE_SETUP
#line 359 "../../cobc/scanner.l"
{
	BEGIN PICTURE_STATE;
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 363 "../../cobc/scanner.l"
{
	if (cobc_in_repository || cobc_cs_check == CB_CS_EXIT) {
		yylval = NULL;
	        RETURN_TOK (FUNCTION);
	}
	BEGIN FUNCTION_STATE;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 371 "../../cobc/scanner.l"
{
	/* String literal */
	cobc_force_literal = 0;
	read_literal (yytext[0], "");
	RETURN_TOK (LITERAL);
}
	YY_BREAK
case 26:
#line 379 "../../cobc/scanner.l"
case 27:
YY_RULE_SETUP
#line 379 "../../cobc/scanner.l"
{
	/* X string literal */
	cobc_force_literal = 0;
	RETURN_TOK (scan_x (yytext + 2, "X"));
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 385 "../../cobc/scanner.l"
{
	/* N national string literal */
	cobc_force_literal = 0;
	/* TODO: national string - needs different handling */
	read_literal (yytext [1], "N");
	RETURN_TOK (LITERAL);
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 393 "../../cobc/scanner.l"
{
	/* NC national character string literal (extension, but
	   same handling as COBOL 2002 national string literal) */
	cobc_force_literal = 0;
	/* TODO: national string - needs different handling */
	read_literal (yytext [2], "NC");
	RETURN_TOK (LITERAL);
}
	YY_BREAK
case 30:
#line 403 "../../cobc/scanner.l"
case 31:
YY_RULE_SETUP
#line 403 "../../cobc/scanner.l"
{
	/* NX string literal */
	cobc_force_literal = 0;
	RETURN_TOK (scan_x (yytext + 3, "NX"));
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 409 "../../cobc/scanner.l"
{
	/* N national string literal */
	cobc_force_literal = 0;
	/* TODO: utf8 string - needs different handling */
	read_literal (yytext [1], "U");
	RETURN_TOK (LITERAL);
}
	YY_BREAK
case 33:
#line 418 "../../cobc/scanner.l"
case 34:
YY_RULE_SETUP
#line 418 "../../cobc/scanner.l"
{
	/* UX string literal */
	cobc_force_literal = 0;
	RETURN_TOK (scan_x (yytext + 3, "UX"));
}
	YY_BREAK
case 35:
#line 425 "../../cobc/scanner.l"
case 36:
YY_RULE_SETUP
#line 425 "../../cobc/scanner.l"
{
	/* Z string literal */
	cobc_force_literal = 0;
	RETURN_TOK (scan_z (yytext + 2, "Z"));
}
	YY_BREAK
case 37:
#line 432 "../../cobc/scanner.l"
case 38:
YY_RULE_SETUP
#line 432 "../../cobc/scanner.l"
{
	/* L string literal */
	cobc_force_literal = 0;
	RETURN_TOK (scan_z (yytext + 2, "L"));
}
	YY_BREAK
case 39:
#line 439 "../../cobc/scanner.l"
case 40:
YY_RULE_SETUP
#line 439 "../../cobc/scanner.l"
{
	/* H hexadecimal/numeric literal */
	cobc_force_literal = 0;
	RETURN_TOK (scan_h (yytext + 2, "H"));
}
	YY_BREAK
case 41:
#line 446 "../../cobc/scanner.l"
case 42:
YY_RULE_SETUP
#line 446 "../../cobc/scanner.l"
{
	/* B boolean/numeric literal */
	cobc_force_literal = 0;
	RETURN_TOK (scan_b (yytext + 2, "B"));
}
	YY_BREAK
case 43:
#line 453 "../../cobc/scanner.l"
case 44:
YY_RULE_SETUP
#line 453 "../../cobc/scanner.l"
{
	/* BX boolean hexadecimal string literal */
	cobc_force_literal = 0;
	RETURN_TOK (scan_x (yytext + 3, "BX"));
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 459 "../../cobc/scanner.l"
{
	/*
	  To avoid subtle silent errors, such as B#021, this rule (and the ones
	  following) here admit some invalid literals which emit errors when
	  they are processed.
	*/
	/* ACUCOBOL binary numeric literal */
	cobc_force_literal = 0;
	RETURN_TOK (scan_b (yytext + 2, "B#"));
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 470 "../../cobc/scanner.l"
{
	/* ACUCOBOL octal numeric literal */
	cobc_force_literal = 0;
	RETURN_TOK (scan_o (yytext + 2, "O#"));
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 476 "../../cobc/scanner.l"
{
	/* HP-COBOL octal numeric literal */
	cobc_force_literal = 0;
	RETURN_TOK (scan_o (yytext + 1, "%"));
}
	YY_BREAK
case 48:
#line 483 "../../cobc/scanner.l"
case 49:
YY_RULE_SETUP
#line 483 "../../cobc/scanner.l"
{
	/* ACUCOBOL hexadecimal numeric literal */
	char type[3] = "x#";
	type[0] = yytext [0];
	cobc_force_literal = 0;
	RETURN_TOK (scan_h (yytext + 2, type));
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 491 "../../cobc/scanner.l"
{
	inside_bracket++;
	RETURN_TOK (TOK_OPEN_PAREN);
}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 496 "../../cobc/scanner.l"
{
	if (inside_bracket > 0) {
		inside_bracket--;
	}
	RETURN_TOK (TOK_CLOSE_PAREN);
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 503 "../../cobc/scanner.l"
{
	int	value;

	cobc_force_literal = 0;
	if (integer_is_label || cobc_in_area_a) {
		yylval = cb_build_reference (yytext);

		if (!cobc_in_procedure) {
			value = atoi (yytext);
			if (value == 66) {
				/* level number 66 */
				RETURN_TOK (SIXTY_SIX);
			} else if (value == 78) {
				/* level number 78 */
				RETURN_TOK (SEVENTY_EIGHT);
			} else if (value == 88) {
				/* level number 88 */
				RETURN_TOK (EIGHTY_EIGHT);
			} else if ((value >= 1 && value <= 49) || value == 77) {
				/* level number (1 through 49, 77) */
				if (cobc_in_area_a) {
					RETURN_TOK (LEVEL_NUMBER_IN_AREA_A);
				} else {
					RETURN_TOK (LEVEL_NUMBER);
				}
			}
		}

		/* Integer label */
		if (cobc_in_area_a) {
			RETURN_TOK (WORD_IN_AREA_A);
		} else {
			RETURN_TOK (WORD);
		}
	}
	/* Numeric literal or referenced integer label
	   remark: all transformations/checks are postponed:
	   literals to tree.c,
	   integer label to typeck.c (cb_build_section_name)
	*/
	yylval = cb_build_numeric_literal (0, yytext, 0);
	RETURN_TOK (LITERAL);
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 547 "../../cobc/scanner.l"
{

	cobc_force_literal = 0;
	if (integer_is_label || cobc_in_area_a) {
		/* Integer label */
		yylval = cb_build_reference (yytext);
		if (cobc_in_area_a) {
			RETURN_TOK (WORD_IN_AREA_A);
		} else {
			RETURN_TOK (WORD);
		}
	}
	/* Numeric literal or referenced integer label
	   remark: all transformations/checks are postponed:
	   literals to tree.c,
	   integer label to typeck.c (cb_build_section_name)
	*/
	yylval = cb_build_numeric_literal (0, yytext, 0);
	RETURN_TOK (LITERAL);
}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 568 "../../cobc/scanner.l"
{
	/* Numeric literal (signed) */
	RETURN_TOK (scan_numeric (yytext));
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 573 "../../cobc/scanner.l"
{
	/* Ignore */
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 577 "../../cobc/scanner.l"
{
	if (inside_bracket) {
		RETURN_TOK (SEMI_COLON);
	}
	/* Ignore */
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 584 "../../cobc/scanner.l"
{
	/* Numeric floating point literal */
	RETURN_TOK (scan_floating_numeric (yytext));
}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 589 "../../cobc/scanner.l"
{
	/* Invalid numeric floating point literal */
	RETURN_TOK (scan_floating_numeric (yytext));
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 594 "../../cobc/scanner.l"
{
	/* Numeric literal */
	RETURN_TOK (scan_numeric (yytext));
}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 599 "../../cobc/scanner.l"
{
	if (inside_bracket) {
		RETURN_TOK (COMMA_DELIM);
	}
	/* Ignore */
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 606 "../../cobc/scanner.l"
{
	/* Numeric floating point literal */
	RETURN_TOK (scan_floating_numeric (yytext));
}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 611 "../../cobc/scanner.l"
{
	/* Invalid numeric floating point literal */
	RETURN_TOK (scan_floating_numeric (yytext));
}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 616 "../../cobc/scanner.l"
{
	/* Numeric literal */
	RETURN_TOK (scan_numeric (yytext));
}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 621 "../../cobc/scanner.l"
{
	unput (',');
}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 625 "../../cobc/scanner.l"
{
	if (inside_bracket) {
		RETURN_TOK (COMMA_DELIM);
	}
	/* Ignore */
}
	YY_BREAK
case 66:
/* rule 66 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 632 "../../cobc/scanner.l"
{
	cobc_force_literal = 1;
	count_lines (yytext);
	RETURN_TOK (END_PROGRAM);
}
	YY_BREAK
case 67:
/* rule 67 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 638 "../../cobc/scanner.l"
{
	cobc_force_literal = 1;
	count_lines (yytext);
	RETURN_TOK (END_FUNCTION);
}
	YY_BREAK
case 68:
/* rule 68 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 644 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (PICTURE_SYMBOL);
}
	YY_BREAK
case 69:
/* rule 69 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 649 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (FROM_CRT);
}
	YY_BREAK
case 70:
/* rule 70 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 654 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (SCREEN_CONTROL);
}
	YY_BREAK
case 71:
/* rule 71 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 659 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (EVENT_STATUS);
}
	YY_BREAK
case 72:
/* rule 72 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 664 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (READY_TRACE);
}
	YY_BREAK
case 73:
/* rule 73 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 669 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (RESET_TRACE);
}
	YY_BREAK
case 74:
/* rule 74 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 674 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (GREATER_OR_EQUAL);
}
	YY_BREAK
case 75:
/* rule 75 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 679 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (GREATER);
}
	YY_BREAK
case 76:
/* rule 76 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 684 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (LESS_OR_EQUAL);
}
	YY_BREAK
case 77:
/* rule 77 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 689 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (LESS);
}
	YY_BREAK
case 78:
/* rule 78 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 694 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (EQUAL);
}
	YY_BREAK
case 79:
/* rule 79 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 699 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (REPLACING);
}
	YY_BREAK
case 80:
/* rule 80 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 704 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (TOP);
}
	YY_BREAK
case 81:
/* rule 81 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 708 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (TOP);
}
	YY_BREAK
case 82:
/* rule 82 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 713 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (BOTTOM);
}
	YY_BREAK
case 83:
/* rule 83 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 717 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (BOTTOM);
}
	YY_BREAK
case 84:
/* rule 84 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 722 "../../cobc/scanner.l"
{
	count_lines (yytext);
	return LINE_LIMIT;
}
	YY_BREAK
case 85:
/* rule 85 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 727 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (NO_ADVANCING);
}
	YY_BREAK
case 86:
/* rule 86 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 732 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (NEXT_PAGE);
}
	YY_BREAK
case 87:
/* rule 87 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 737 "../../cobc/scanner.l"
{
	count_lines (yytext);
	return NEXT_GROUP;
}
	YY_BREAK
case 88:
/* rule 88 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 742 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (NOT_SIZE_ERROR);
}
	YY_BREAK
case 89:
/* rule 89 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 747 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (SIZE_ERROR);
}
	YY_BREAK
case 90:
/* rule 90 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 752 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (NOT_ON_ESCAPE);
}
	YY_BREAK
case 91:
/* rule 91 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 757 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (NOT_ON_EXCEPTION);
}
	YY_BREAK
case 92:
/* rule 92 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 762 "../../cobc/scanner.l"
{
	/* Note: plain ESCAPE is directly matched via registered words */
	count_lines (yytext);
	RETURN_TOK (ON_ESCAPE);
}
	YY_BREAK
case 93:
/* rule 93 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 768 "../../cobc/scanner.l"
{
	/* Note: plain EXCEPTION is directly matched via registered words */
	count_lines (yytext);
	RETURN_TOK (ON_EXCEPTION);
}
	YY_BREAK
case 94:
/* rule 94 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 774 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (NOT_ON_OVERFLOW);
}
	YY_BREAK
case 95:
/* rule 95 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 779 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (NOT_AT_END);
}
	YY_BREAK
case 96:
/* rule 96 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 784 "../../cobc/scanner.l"
{
	/* Note: plain END is directly matched via registered words */
	count_lines (yytext);
	RETURN_TOK (AT_END);
}
	YY_BREAK
case 97:
/* rule 97 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 790 "../../cobc/scanner.l"
{
	/* Note: plain OVERFLOW is directly matched via registered words */
	count_lines (yytext);
	RETURN_TOK (TOK_OVERFLOW);
}
	YY_BREAK
case 98:
/* rule 98 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 796 "../../cobc/scanner.l"
{
	/* TODO: if those words are not reserved -> directly return */
	count_lines (yytext);
	RETURN_TOK (NOT_EOP);
}
	YY_BREAK
case 99:
/* rule 99 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 802 "../../cobc/scanner.l"
{
	/* Note: plain END-OF-PAGE / EOP is directly matched via registered words */
	/* TODO: if those words are not reserved -> directly return */
	count_lines (yytext);
	RETURN_TOK (EOP);
}
	YY_BREAK
case 100:
/* rule 100 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 809 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (NOT_INVALID_KEY);
}
	YY_BREAK
case 101:
/* rule 101 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 814 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (INVALID_KEY);
}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 819 "../../cobc/scanner.l"
{
	if (cobc_in_procedure) {
		RETURN_TOK (INVALID_KEY);
	} else {
		/* note: INVALID is a reserved word in all dialects,
		         otherwise we'd lookup and return WORD as necessary */
		RETURN_TOK (INVALID);
	}
}
	YY_BREAK
case 103:
/* rule 103 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 829 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (NO_DATA);
}
	YY_BREAK
case 104:
/* rule 104 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 834 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (DATA);
}
	YY_BREAK
case 105:
/* rule 105 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 839 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (UPON_ENVIRONMENT_NAME);
}
	YY_BREAK
case 106:
/* rule 106 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 844 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (UPON_ENVIRONMENT_VALUE);
}
	YY_BREAK
case 107:
/* rule 107 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 849 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (UPON_ARGUMENT_NUMBER);
}
	YY_BREAK
case 108:
/* rule 108 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 854 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (UPON_COMMAND_LINE);
}
	YY_BREAK
case 109:
/* rule 109 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 859 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (EXCEPTION_CONDITION);
}
	YY_BREAK
case 110:
/* rule 110 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 864 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (EC);
}
	YY_BREAK
case 111:
/* rule 111 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 8);
(yy_c_buf_p) = yy_cp = yy_bp + 8;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 869 "../../cobc/scanner.l"
{
	count_lines (yytext);
	if (!lookup_reserved_word ("SUPPRESS")) {
		RETURN_TOK (WORD);
	}
	if (cobc_in_xml_generate_body || cobc_in_json_generate_body) {
		/*
		  Using the standard SUPPRESS token in JSON/XML GENERATE causes
                  a shift/reduce error - the SUPPRESS could be the start of the
		  SUPPRESS clause or the start of a SUPPRESS statement. While we
		  could alter shift precedence to get the result we implement
		  here (viz. assuming the SUPPRESS belongs to JSON/XML GENERATE),
                  our current style is for bison to run with no errors.
		*/
		RETURN_TOK (SUPPRESS_XML);
	} else {
		RETURN_TOK (SUPPRESS);
	}
}
	YY_BREAK
case 112:
/* rule 112 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 4);
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 889 "../../cobc/scanner.l"
{
	/* FIXME: seems to wok fine with SUPPRESS, but not here ... */
	count_lines (yytext);
	if (!lookup_reserved_word ("SEND")) {
		RETURN_TOK (WORD);
	}
#if 0
	if (current_program->cd_list) {
		/*
		  Using the standard SEND token in causes shift/reduce errors
		  as it could either be SEND cd-name (COBOL until 85) or
		  SEND (in MCS context COBOL 202x).
		*/
		RETURN_TOK (SEND);
	} else {
		RETURN_TOK (SEND_CD);
	}
#else
	RETURN_TOK (SEND);
#endif
}
	YY_BREAK
case 113:
/* rule 113 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 4);
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 911 "../../cobc/scanner.l"
{
	count_lines (yytext);
	if (cobc_in_xml_generate_body) {
		/*
		  Using the standard WHEN token in XML GENERATE causes a
		  shift/reduce error - the WHEN could be the start of the
		  WHEN clause or the start of a WHEN statement. While we
		  could alter shift precedence to get the result we implement
		  here (viz. assuming the WHEN belongs to XML GENERATE), our
		  current style is for bison to run with no errors.
		*/
		RETURN_TOK (WHEN_XML);
	} else {
		RETURN_TOK (WHEN);
	}
}
	YY_BREAK
case 114:
/* rule 114 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 928 "../../cobc/scanner.l"
{
	count_lines (yytext);
	yylval = cb_build_reference ("ALTERNATE CONSOLE");
	RETURN_TOK (WORD);
}
	YY_BREAK
case 115:
/* rule 115 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 934 "../../cobc/scanner.l"
{
	/* ACUCOBOL extension: switch-names with space and with letter */
	char name[10];

	/* FIXME: move the code for filling "name" here and first
	          check with "lookup_system_name (name) != NULL"
	          if we actually want to do this,
			  otherwise return 2 (!) WORD tokens (by adding a queue
			  of tokens to be returned)
	*/
	if (cobc_in_procedure) {
		 /* unput characters */
		yylval = cb_build_reference ("SWITCH");
		if (isdigit((unsigned char)yytext[yyleng-2])) {
			unput (yytext[yyleng-1]);
			unput (yytext[yyleng-2]);
		} else {
			unput (yytext[yyleng-1]);
		}
	} else {
		 /* we need to return a single word, reverted later in parser.y */
		strcpy (name, yytext);
		name[6] = '_';
		yylval = cb_build_reference (name);
	}
	RETURN_TOK (WORD);
}
	YY_BREAK
case 116:
/* rule 116 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 962 "../../cobc/scanner.l"
{
	count_lines (yytext);
	RETURN_TOK (LENGTH_OF);
}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 967 "../../cobc/scanner.l"
{
	struct cb_level_78		*p78;
	struct cb_intrinsic_table	*cbp;
	struct cobc_reserved		*resptr;
	struct cb_text_list		*tlp;
	cb_tree				x;
	cb_tree				l;
	struct cb_program		*program;

	cb_check_word_length ((unsigned int)yyleng, yytext);

	/* Check Intrinsic FUNCTION name without keyword */
	if ((cobc_in_procedure && (functions_are_all || cb_intrinsic_list ||
	     current_program->function_spec_list)) || cobc_in_repository) {
		cbp = lookup_intrinsic (yytext, 0);
		if (cbp) {
			if (cobc_in_repository) {
				yylval = cb_build_alphanumeric_literal (yytext, (size_t)yyleng);
				RETURN_TOK (FUNCTION_NAME);
			}
			if (functions_are_all) {
				yylval = cb_build_reference (yytext);
				RETURN_TOK ((enum yytokentype)(cbp->token));
			}
			for (tlp = cb_intrinsic_list; tlp; tlp = tlp->next) {
				if (!strcasecmp (yytext, tlp->text)) {
					yylval = cb_build_reference (yytext);
					RETURN_TOK ((enum yytokentype)(cbp->token));
				}
			}
			l = current_program->function_spec_list;
			for (; l; l = CB_CHAIN(l)) {
				x = CB_VALUE (l);
				if (!strcasecmp (yytext,
						 (char *)(CB_LITERAL(x)->data))) {
					yylval = cb_build_reference (yytext);
					RETURN_TOK ((enum yytokentype)(cbp->token));
				}
			}
		}
	}

	/* Bail early for (END) PROGRAM-ID when not a literal */
	if (unlikely (cobc_force_literal)) {
		/* Force PROGRAM-ID / END PROGRAM */
		cobc_force_literal = 0;
		if (cb_fold_call) {
			yylval = cb_build_reference (yytext);
			RETURN_TOK (PROGRAM_NAME);
		} else {
			yylval = cb_build_alphanumeric_literal (yytext, (size_t)yyleng);
			RETURN_TOK (LITERAL);
		}
	}

	/* Check reserved word */
	resptr = lookup_reserved_word (yytext);
	if (resptr != NULL) {
		if (resptr->nodegen) {
			/* Save location for terminator checking */
			/* Misuse comment tree to mark statement */
			yylval = cb_build_comment (NULL);
		} else {
			yylval = NULL;
		}
		RETURN_TOK (resptr->token);
	}

	/* New user-defined word in REPOSITORY entry */
	if (cobc_in_repository) {
		yylval = cb_build_reference (yytext);
		RETURN_TOK (WORD);
	}

	/* Direct recursive reference in function */
	if (current_program->prog_type == COB_MODULE_TYPE_FUNCTION
		   && !functions_are_all
		   && !strcasecmp (yytext, current_program->orig_program_id)) {
		yylval = cb_build_reference (yytext);
		RETURN_TOK (USER_FUNCTION_NAME);
	}

	/* Check prototype names */
	for (l = current_program->user_spec_list; l; l = CB_CHAIN (l)) {
		x = CB_VALUE (l);
		if (!strcasecmp (yytext, CB_PROTOTYPE (x)->name)) {
			yylval = cb_build_reference (yytext);
			RETURN_TOK (USER_FUNCTION_NAME);
		}
	}
	if (cobc_allow_program_name) {
		for (l = current_program->program_spec_list; l; l = CB_CHAIN (l)) {
			x = CB_VALUE (l);
			if (!strcasecmp (yytext, CB_PROTOTYPE (x)->name)) {
				yylval = cb_build_reference (yytext);
				RETURN_TOK (PROGRAM_NAME);
			}
		}
	}

	/* Check user programs */
	if (cobc_in_id) {
		program = cb_find_defined_program_by_name (yytext);
		if (program) {
			yylval = cb_build_reference (yytext);
			RETURN_TOK (PROGRAM_NAME);
		}
	}

	/* User word */

	/* Check local, global and source global CONSTANT (78) items */

	for (p78 = top_78_ptr; p78; p78 = p78->glob_next) {
		if (strcasecmp (yytext, p78->fld_78->name) == 0) {
			if (unlikely (non_const_word)) {
				if (p78->prog == current_program) {
					cb_error (_("a constant may not be used here - '%s'"), yytext);
					yylval = cb_error_node;
					RETURN_TOK (WORD);
				}
				if (p78->chk_const) {
					p78->not_const = 1;
				}
				break;
			}
			if (p78->chk_const && p78->not_const) {
				break;
			}
			x = p78->fld_78->values;
			if (CB_LITERAL_P (x)) {
				/* duplicate the constant literal
				   to assign current source location */
				yylval = cobc_parse_malloc (sizeof (struct cb_literal));
				memcpy (yylval, x, sizeof (struct cb_literal));
				SET_LOCATION (yylval);
			} else {
				/* Note: we cannot do this for cb_zero and friends,
				         as those have sepcial meanings and are checked
						 by tree comparision only */
				yylval = x;
			}
			RETURN_TOK (LITERAL);
		}
	}

	yylval = cb_build_reference (yytext);

	/* Special name handling */
	if (CB_WORD_COUNT (yylval) > 0 && CB_WORD_ITEMS (yylval)) {
		x = CB_VALUE (CB_WORD_ITEMS (yylval));
		if (CB_SYSTEM_NAME_P (x)) {
			RETURN_TOK (MNEMONIC_NAME);
		} else if (CB_CLASS_NAME_P (x)) {
			RETURN_TOK (CLASS_NAME);
		}
	}

	if (cobc_in_area_a) {
		RETURN_TOK (WORD_IN_AREA_A);
	} else {
		RETURN_TOK (WORD);
	}
}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 1132 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (LESS_OR_EQUAL);
}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 1137 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (GREATER_OR_EQUAL);
}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 1142 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (NOT_EQUAL);
}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 1147 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (EXPONENTIATION);
}
	YY_BREAK
case 122:
/* rule 122 can match eol */
YY_RULE_SETUP
#line 1152 "../../cobc/scanner.l"
{
	if (last_token_is_dot || strlen (yytext) > 1) {
		cb_warning (COBC_WARN_FILLER, _("ignoring redundant ."));
	}

	if (!last_token_is_dot) {
		last_token_is_dot = 1;
		yylval = NULL;
		RETURN_TOK (TOK_DOT);
	}
}
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 1164 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (TOK_AMPER);
}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 1169 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (TOK_COLON);
}
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 1174 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (TOK_EQUAL);
}
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 1179 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (TOK_DIV);
}
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 1184 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (TOK_MUL);
}
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 1189 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (TOK_PLUS);
}
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 1194 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (TOK_MINUS);
}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 1199 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (TOK_LESS);
}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 1204 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (TOK_GREATER);
}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 1209 "../../cobc/scanner.l"
{
	int	c;

	cb_error (_("invalid symbol '%s' - skipping word"), yytext);
	while ((c = input ()) != EOF) {
		if (c == '\n' || c == ' ') {
			break;
		}
	}
	if (c != EOF) {
		unput (c);
	}
}
	YY_BREAK

case 133:
YY_RULE_SETUP
#line 1225 "../../cobc/scanner.l"
{
	/* Ignore */
  }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 1228 "../../cobc/scanner.l"
{
	BEGIN INITIAL;
	scan_picture (yytext);
	RETURN_TOK (PICTURE);
  }
	YY_BREAK


case 135:
YY_RULE_SETUP
#line 1236 "../../cobc/scanner.l"
{
	struct cb_intrinsic_table	*cbp;
	cb_tree				l;
	cb_tree				x;

	BEGIN INITIAL;
	yylval = cb_build_reference (yytext);
	for (l = current_program->user_spec_list; l; l = CB_CHAIN(l)) {
		x = CB_VALUE (l);
		if (!strcasecmp (yytext, CB_PROTOTYPE (x)->name)) {
			RETURN_TOK (USER_FUNCTION_NAME);
		}
	}
	cbp = lookup_intrinsic (yytext, 0);
	if (cbp) {
		RETURN_TOK ((enum yytokentype)(cbp->token));
	}
	RETURN_TOK (FUNCTION_NAME);
  }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 1255 "../../cobc/scanner.l"
{
	yylval = NULL;
	RETURN_TOK (yytext[0]);
  }
	YY_BREAK

case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(DECIMAL_IS_PERIOD):
case YY_STATE_EOF(DECIMAL_IS_COMMA):
case YY_STATE_EOF(PICTURE_STATE):
case YY_STATE_EOF(FUNCTION_STATE):
#line 1261 "../../cobc/scanner.l"
{
	/* At EOF - Clear variables */
	clear_constants ();
	last_token_is_dot = 0;
	cobc_in_area_a = 0;
	integer_is_label = 0;
	inside_bracket = 0;
	cobc_force_literal = 0;
	yyterminate ();
}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 1272 "../../cobc/scanner.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 3770 "scanner.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1094 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1094 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 1093);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current token.
 * 
 */

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 1272 "../../cobc/scanner.l"


static void
error_literal (const char *type, const char *literal, unsigned int literal_error)
{
	if (!literal_error) {
		char		lit_out[CB_ERR_LITMAX + 1] = { 0 };
		/* snip literal for output, if too long or,
			unlikely error case, has a line break */
		literal_for_diagnostic (lit_out, literal);

#if 0 /* national literal, check for different truncation and wcslen
		 or not show it at all */
		if (strcmp (type, "national") == 0) {
			cb_error (_("invalid national literal"), lit_out);
		} else {
#endif
			if (strcmp (type, "") == 0) {
				cb_error (_("invalid literal: '%s'"), lit_out);
			} else if (strcmp (type, "hex") == 0) {
				cb_error (_("invalid hexadecimal literal: '%s'"), lit_out);
			} else if (strcmp (type, "num") == 0) {
				cb_error (_("invalid numeric literal: '%s'"), lit_out);
			} else if (strcmp (type, "float") == 0) {
				cb_error (_("invalid floating-point literal: '%s'"), lit_out);
			} else {
				cb_error (_("invalid %s literal: '%s'"), type, lit_out);
			}
#if 0 /* national literal */
		}
#endif
	}
	cb_error ("%s", err_msg);
}

static void
read_literal (const char mark, const char *type)
{
	size_t		i;
	int		c;
	unsigned int	literal_error = 0;

	i = 0;
	/* read until a not-escaped mark is found (see break)
	   or (unlikely) we reach EOF */
	/* NO early exit possible as the literal has to be consumed */
	while ((c = input ()) != EOF) {
#if EOF != 0
		if (unlikely (c == 0)) break;	/* fixes unexpected error case */
#endif
		if (!literal_error) {
			if (unlikely (i + 1 == plex_size)) {
				plex_size *= 2;
				if (unlikely (plex_size > (cb_lit_length + 1))) {
					plex_size = (size_t)cb_lit_length + 1;
				}
				plex_buff = cobc_realloc (plex_buff, plex_size);
			}
			plex_buff[i] = (cob_u8_t)c;
		}
		if (c == mark && (c = input ()) != (int)mark) {
			if (c == '-') {
				/* Free format continuation ("a"- 'b'- ) */
				/* Hack it as concatenation */
				unput ('&');
			} else {
				if (c == EOF || c == 0) break;
				unput (c);
			}
			break;
		}
		/* check literal size here as we have to adjust and check
		   for (escaped) mark before checking the max length */
		if (unlikely (i++ == cb_lit_length)) {
			snprintf (err_msg, COB_MINI_MAX,
				_("literal length exceeds %u characters"),
				cb_lit_length);
			plex_buff[cb_lit_length] = 0; /* ensure valid C-string for error message */
			error_literal ("", plex_buff, literal_error);
			if (!literal_error) {
				literal_error = cb_lit_length;
			}
		}
	}
	if (c == EOF
#if EOF != 0
	 || c == 0 /* fixes unexpected error case */
#endif
		) {
			snprintf (err_msg, COB_MINI_MAX,
				_("missing terminating %c character"), mark);
			plex_buff[i] = 0; /* ensure valid C-string for error message */
			error_literal ("", plex_buff, literal_error);
			if (!literal_error) {
				literal_error = i;
			}
	}

	/* FIXME: Exact behavior should depend on level of support:
	    * "OK"      => standard behavior, e.g. normal items filled with spaces/
	                   zeros, DYNAMIC LENGTH items made empty
	    * "warning" => current implementation, interpret '' as SPACE/ZERO
	    * "ignore"  => assume a space without warning; make sure zero length
	                   items work everywhere (should do as we support zero
	                   lengths via ODO items already)
	*/
	if (!i) {
		cb_verify (cb_zero_length_lit, _("zero-length literal"));
		cb_warning (COBC_WARN_FILLER,
			    type[0] == 'N' ?
			    _("national literal has zero length; a SPACE will be assumed") :
			    _("alphanumeric literal has zero length; a SPACE will be assumed"));
		plex_buff[i++] = ' ';
	} else if (i > cb_lit_length) {
		i = cb_lit_length;
	}

	/* build literal with given size */
	plex_buff[i] = 0;
	if (type[0] != 'N') {
		yylval = cb_build_alphanumeric_literal (plex_buff, i);
		if (type[0] == 'U') {
			CB_UNFINISHED (_("UTF-8 literal"));
		}
	} else {
		/* poor-man's conversion iso-8859 -> utf-16 */
		/* "!a0" = x'21613000' -> nx'00210061003000' */
		size_t new_size = i * 2;
		if (new_size + 1 > plex_size) {
			plex_size = new_size + 1;
			plex_buff = cobc_realloc (plex_buff, plex_size);
		}
		plex_buff[new_size] = 0;
		while (i) {
			i--;
			plex_buff[i * 2 + 1] = plex_buff [i];
			plex_buff[i * 2] = 0;
		}
		i = new_size;
		if (type[1] != 'C') {
			if (cb_verify (cb_national_literals, _("national literal"))) {
				CB_UNFINISHED (_("national literal"));
			}
		} else {
			if (cb_verify (cb_nationalc_literals, _("national-character literal"))) {
				CB_UNFINISHED (_("national literal"));
			}
		}
		yylval = cb_build_national_literal (plex_buff, i);
	}
}

static int
scan_x (const char *text, const char *type)
{
	char		*p;
	char		*e;
	char		*dst;
	size_t		curr_len;
	size_t		result_len;
	char		c;
	unsigned int	literal_error = 0;

	/* Remark:
	   The standard allows for 8,191 (normal/national/boolean) character positions */

	/* curr_len includes the terminating quote
	   and has to be adjusted according to type */

	curr_len = strlen (text);
	curr_len--;
	if (curr_len == 0) {
		cb_verify (cb_zero_length_lit, _("zero-length literal"));
		memset (plex_buff, 0, 5);
		cb_warning (COBC_WARN_FILLER,
			    _("hexadecimal literal has zero length; X'00' will be assumed"));
		if (type[0] == 'B') {
			yylval = cb_build_numeric_literal (0, "0", 0);
		} else if (type[0] != 'N') {
			yylval = cb_build_alphanumeric_literal (plex_buff, 1);
		} else {
			yylval = cb_build_national_literal (plex_buff, 1);
		}
		RETURN_TOK (LITERAL);
	}

	/* ensure buffers don't get too big */
	if (curr_len > (size_t)cb_lit_length + 1) {
		curr_len = cb_lit_length + 1;
	}
	if (unlikely (curr_len + 1 > plex_size)) {
		plex_size = curr_len + 1;
		cobc_free (plex_buff);
		plex_buff = cobc_malloc (plex_size);
	}
	memcpy (plex_buff, text, curr_len);
	if (type[0] == 'X' || type [0] == 'U') {
		result_len = curr_len / 2; /* characters, two half-bytes (hex) = 1 byte */
	} else if (type[0] == 'B') {
		result_len = curr_len * 4; /* boolean characters B -> 1110 */
		if (!cb_verify (cb_hexadecimal_boolean, _("hexadecimal-boolean literal"))) {
			yylval = cb_build_numeric_literal (0, "0", 0);
			RETURN_TOK (LITERAL);
		}

		/* GnuCOBOL currently only support 64 bit booleans */
		if (unlikely (result_len > 64)) {
			snprintf (err_msg, COB_MINI_MAX,
				_("literal length %lu exceeds %u characters"),
				  (unsigned long) result_len, 64);
			error_literal (type, plex_buff, literal_error++);
			/* we'll get an overflow below, but that's no problem,
			   an alternative would be to incement *text to only parse 64 / 4
			   characters but that leads to not verified data, which is
			   more important as the compilation will error-exit in any case */
		}
	} else /* type N */ {
		result_len = curr_len / (2 * COB_NATIONAL_SIZE);
		if (!cb_verify (cb_national_hex_literals, _("hexadecimal-national literal"))) {
			yylval = cb_build_national_literal ("", 1);
			RETURN_TOK (LITERAL);
		} else {
			CB_UNFINISHED (_("national literal"));
		}
	}
	if (unlikely (result_len > cb_lit_length)) {
		snprintf (err_msg, COB_MINI_MAX,
			_("literal length %lu exceeds %u characters"),
			  (unsigned long) result_len, cb_lit_length);
		error_literal (type, plex_buff, literal_error++);
	}

	p = (char *)text;
	e = (char *)p + curr_len;
	dst = plex_buff;

	if (unlikely(type[0] == 'B')) {
		/* hexadecimal-boolean */
		cob_u64_t	val = 0;
		for (; *p != *e; p++) {
			c = *p;
			if ('0' <= c && c <= '9') {
				c = c - '0';
			} else if ('A' <= c && c <= 'F') {
				c = c - 'A' + 10;
			} else if ('a' <= c && c <= 'f') {
				c = c - 'a' + 10;
			} else {
				snprintf (err_msg, COB_MINI_MAX,
					_("literal contains invalid character '%c'"), c);
				if (likely (literal_error == 0)) {
					memcpy (plex_buff, text, curr_len + 1);
					plex_buff[curr_len] = 0;
				}
				error_literal (type, plex_buff, literal_error++);
				/* By not breaking immediately, we detect any following
				   invalid chars
				*/
				c = 0;
			}
			val = (val << 4) + c;
		}
		sprintf ((char *)plex_buff, CB_FMT_LLU, val);
		yylval = cb_build_numeric_literal (0, (const void *)plex_buff, 0);

	} else {

		/* hexadecimal */
		int		high = 1;
		for (; *p != *e; p++) {
			c = (int) *p;
			if ('0' <= c && c <= '9') {
				c = c - '0';
			} else if ('A' <= c && c <= 'F') {
				c = c - 'A' + 10;
			} else if ('a' <= c && c <= 'f') {
				c = c - 'a' + 10;
			} else {
				snprintf (err_msg, COB_MINI_MAX,
					_("literal contains invalid character '%c'"), c);
				if (likely (literal_error == 0)) {
					memcpy (plex_buff, text, curr_len + 1);
					plex_buff[curr_len] = 0;
				}
				error_literal (type, plex_buff, literal_error++);
				/* By not breaking immediately, we detect any following
					invalid chars
				*/
				c = 0;
			}
			if (high) {
				*dst = (cob_u8_t)(c << 4);
			} else {
				*dst++ += (cob_u8_t)c;
			}
			high = 1 - high;
		}

		if (!high) {
			/* This is non-standard behaviour */
			snprintf (err_msg, COB_MINI_MAX,
				_("literal does not have an even number of digits"));
			if (likely (literal_error == 0)) {
				memcpy (plex_buff, text, curr_len + 1);
				plex_buff[curr_len] = 0;
			}
			error_literal (type, plex_buff, literal_error++);
		}
		/* TODO: for type U needs additional checks */
		if (type[0] != 'N') {
			yylval = cb_build_alphanumeric_literal (plex_buff, (size_t)(dst - plex_buff));
		} else {
			yylval = cb_build_national_literal (plex_buff, (size_t)(dst - plex_buff));
		}
	}

	RETURN_TOK (LITERAL);
}

static int
scan_z (const char *text, const char *type)
{
	/* curr_len includes the terminating quote */
	size_t		curr_len = strlen (text);

	if (curr_len == 1) {
		curr_len--;
	    snprintf (err_msg, COB_MINI_MAX,
			_("%s literals must contain at least one character"),
			type);
		error_literal (type, "", 0);
		yylval = cb_build_alphanumeric_literal ("", 1);
		RETURN_TOK (LITERAL);
	}
	if ((unsigned long)(curr_len - 1) > cb_lit_length) {
		curr_len--;
		snprintf (err_msg, COB_MINI_MAX,
			_("literal length %lu exceeds %u characters"),
			  (unsigned long) curr_len, cb_lit_length);
		error_literal (type, text, 0);
		curr_len = cb_lit_length + 1; /* ensure buffers don't get too big */
	}
	if (curr_len > plex_size) {
		plex_size = curr_len;
		cobc_free (plex_buff);
		plex_buff = cobc_malloc (plex_size);
	}
	memcpy (plex_buff, text, curr_len);
	plex_buff[curr_len - 1] = 0;

	/* Count is correct here as the trailing quote is now a null */
	yylval = cb_build_alphanumeric_literal (plex_buff, curr_len);
	if (type[0] == 'L') {
		CB_LITERAL(yylval)->llit = 1;
	}
	RETURN_TOK (LITERAL);
}

static int
scan_h (const char *text, const char *type)
{
	size_t		curr_len;
	char		*p;
	cob_u64_t	val = 0;
	int		c;
	unsigned int	literal_error = 0;

	if (type[1] == '#'
	 && !cb_verify (cb_acu_literals, _("ACUCOBOL numeric literal"))) {
		/* note: early exit with valid literal */
		yylval = cb_build_numeric_literal (0, "0", 0);
		RETURN_TOK (LITERAL);
	}

	/* curr_len can include the terminating quote */
	curr_len = strlen (text);
	memcpy (plex_buff, text, curr_len + 1);
	if (type[1] != '#') {
		curr_len--;
		if (curr_len == 0) {
			cb_error (_("H literals must contain at least one character"));
			yylval = cb_build_numeric_literal (0, "0", 0);
			RETURN_TOK (LITERAL);
		}
		plex_buff[curr_len] = 0;
	}
	if (unlikely (curr_len > 16)) {
		snprintf (err_msg, COB_MINI_MAX,
			_("literal length %lu exceeds %u characters"),
			  (unsigned long) curr_len,  16);
		error_literal ("hex", plex_buff, literal_error++);
	}

	for (p = plex_buff; *p != 0; p++) {
		c = (int) *p;
		if ('0' <= c && c <= '9') {
			c = c - '0';
		} else if ('A' <= c && c <= 'F') {
			c = c - 'A' + 10;
		} else if ('a' <= c && c <= 'f') {
			c = c - 'a' + 10;
		} else {
			snprintf (err_msg, COB_MINI_MAX,
				_("literal contains invalid character '%c'"), c);
			error_literal (type, plex_buff, literal_error++);
			/* By not breaking immediately, we detect any following
				invalid chars
			*/
			c = 0;
		}

		val = (val << 4) + c;
	}

	if (type[1] == '#') {
		/* limit for ACUCOBOL literals: UINT_MAX */
		if (val > UINT_MAX) {
			if (curr_len <= 16) {
				snprintf (err_msg, COB_MINI_MAX,
					_("literal exceeds limit %u"), UINT_MAX);
				error_literal (type, plex_buff, literal_error++);
			}
			val = UINT_MAX;
		}
	}

	/* Duplication? */
	sprintf ((char *)plex_buff, CB_FMT_LLU, val);
	yylval = cb_build_numeric_literal (0, (const void *)plex_buff, 0);

	RETURN_TOK (LITERAL);
}

static int
scan_b (const char *text, const char *type)
{
	/* FIXME: COBOL 2014 allows up to 8,192 boolean characters
	          COBOL 2002 allows up to   160 boolean characters
	          --> both identical to "literal-length" maximum
	          GnuCOBOL currently only supports 64 boolean characters,
			  more need a different storage
	*/

	size_t		curr_len;
	char		*p;
	cob_u64_t	val = 0;
	int		c;
	unsigned int	literal_error = 0;

	/* curr_len can include the terminating quote */
	curr_len = strlen (text);

	if (type[1] == 0) {
		if (!cb_verify (cb_numeric_boolean, _("numeric boolean literal"))) {
			/* early exit possible as complete literal is consumed */
			curr_len = 0;
		}
		if (curr_len == 1) {
			cb_verify (cb_zero_length_lit, _("zero-length literal"));
			cb_warning (COBC_WARN_FILLER,
				    _("Boolean literal has zero length; B'0' will be assumed"));
		}
		if (curr_len <= 1) {
			/* FIXME: we should really build a boolean literal... */
			yylval = cb_build_numeric_literal (0, "0", 0);
			RETURN_TOK (LITERAL);
		}
	} else {
		if (!cb_verify (cb_acu_literals, _("ACUCOBOL numeric literal"))) {
			yylval = cb_build_numeric_literal (0, "0", 0);
			RETURN_TOK (LITERAL);
		}
	};
	if (unlikely (curr_len >= plex_size)) {
		curr_len = plex_size - 1;
	}
	memcpy (plex_buff, text, curr_len + 1);
	if (type[1] == 0) {
		curr_len--;
	}
	plex_buff[curr_len] = 0;
	if (unlikely (curr_len > 64)) {
		snprintf (err_msg, COB_MINI_MAX,
			_("literal length %lu exceeds %u characters"),
			  (unsigned long) curr_len, 64);
		error_literal (type, plex_buff, literal_error++);
		/* we'll get an overflow below, but that's no problem,
		   an alternative would be to incement *text to only parse 64 / 4
		   characters but that leads to not verified data, which is
		   more important as the compilation will error-exit in any case */
	}

	for (p = plex_buff; *p != 0; p++) {
		c = (int) *p;
		if (c == '0') {
			c = 0;
		} else if (c == '1') {
			c = 1;
		} else {
			snprintf (err_msg, COB_MINI_MAX,
				_("literal contains invalid character '%c'"), c);
			error_literal (type, plex_buff, literal_error++);
			c = 0;
		}

		val = (val << 1) + c;
	}
	if (type[1] == '#') {
		/* limit for ACUCOBOL literals: UINT_MAX */
		if (val > UINT_MAX) {
			if (curr_len <= 64) {
				snprintf (err_msg, COB_MINI_MAX,
					_("literal exceeds limit %u"), UINT_MAX);
				error_literal (type, plex_buff, literal_error);
			}
			val = UINT_MAX;
		}
	}

	sprintf ((char *)plex_buff, CB_FMT_LLU, val);
	/* FIXME: we should likely build a boolean literal ... */
	yylval = cb_build_numeric_literal (0, (const void *)plex_buff, 0);

	RETURN_TOK (LITERAL);
}

static int
scan_o (const char *text, const char *type)
{
	size_t		curr_len;
	cob_u64_t	val = 0;
	char		*p;
	char		c;
	unsigned int	literal_error = 0;

	if (type[0] == '%') {
		if (!cb_verify (cb_hp_octal_literals, _("HP COBOL octal literal"))) {
			/* early exit possible as complete literal is consumed */
			yylval = cb_build_numeric_literal (0, "0", 0);
			RETURN_TOK (LITERAL);
		}
	} else {
		if (!cb_verify (cb_acu_literals, _("ACUCOBOL numeric literal"))) {
			/* early exit possible as complete literal is consumed */
			yylval = cb_build_numeric_literal (0, "0", 0);
			RETURN_TOK (LITERAL);
		}
	}

	curr_len = strlen (text);
	memcpy (plex_buff, text, curr_len + 1);
	if (unlikely (curr_len > 22)) {
		snprintf (err_msg, COB_MINI_MAX,
			  _("literal length %lu exceeds %u characters"),
			  (unsigned long) curr_len, 22);
		error_literal (type, plex_buff, literal_error++);
	}

	for (p = plex_buff; *p != 0; p++) {
		c = *p;
		if ('0' <= c && c <= '7') {
			c = c - '0';
		} else {
			snprintf (err_msg, COB_MINI_MAX,
				_("literal contains invalid character '%c'"), c);
			error_literal (type, plex_buff, literal_error++);
			c = 0;
		}

		val = (val << 3) + c;
	}
	/* limit for ACUCOBOL literals: UINT_MAX */
	if (val > UINT_MAX) {
		if (curr_len <= 22) {
			snprintf (err_msg, COB_MINI_MAX,
				_("literal exceeds limit %u"), UINT_MAX);
			error_literal (type, plex_buff, literal_error++);
		}
		val = UINT_MAX;
	}

	if (type[0] == '%') {
		/* actually the rules specify that the literal type is context-sensitive
		   and for alphanumeric right-filled with NULL, therefore we'd need
		   a special type of literal here */
		CB_UNFINISHED ("HP COBOL octal literals");
#if 0	/* activate to have all %literals to be alphanumeric */
		char xbuff[19];
		sprintf ((char *)&xbuff, "'%X'", (unsigned int)val);
		cobc_force_literal = 0;
		RETURN_TOK (scan_x ((const char *)&xbuff + 1, "X"));
#endif
	}

	sprintf ((char *)plex_buff, CB_FMT_LLU, val);
	yylval = cb_build_numeric_literal (0, (const void *)plex_buff, 0);

	RETURN_TOK (LITERAL);
}

static int
get_sign (const char sign)
{
	if (sign == '+') {
		return 1;
	} else if (sign == '-') {
		return -1;
	} else {
		return 0;
	}
}

#define INCREMENT_IF_SIGNED(text, sign) \
	do {				\
		if (sign) {		\
			(text)++;	\
		}			\
	} ONCE_COB

static int
scan_numeric (const char *text)
{
	char		*p = (char *)text;
	char		*s;
	int 		sign;
	int 		scale;
	size_t	curr_len;

	/* Get sign */
	sign = get_sign (*p);
	INCREMENT_IF_SIGNED (p, sign);

	/* Get decimal point */
	s = strchr (p, current_program->decimal_point);
	if (s) {
		scale = (int)strlen (s) - 1;
		/* Remove decimal point */
		/* Moves trailing null */
		memmove (s, s + 1, (size_t)scale + 1);
	} else {
		scale = 0;
	}

	/* Note that leading zeroes are not removed from the literal. */

	curr_len = strlen (p);

	if (curr_len > COB_MAX_DIGITS) {
		/* Absolute limit */
		snprintf (err_msg, COB_MINI_MAX,
			  _("literal length %lu exceeds maximum of %u digits"),
			  (unsigned long) curr_len, COB_MAX_DIGITS);
		error_literal ("num", text, 0);
		p[COB_MAX_DIGITS] = 0;
	} else if (curr_len > cb_numlit_length) {
		snprintf (err_msg, COB_MINI_MAX,
			  _("literal length %lu exceeds %u digits"),
			  (unsigned long) curr_len, cb_numlit_length);
		error_literal ("num", text, 0);
	}
	yylval = cb_build_numeric_literal (sign, p, scale);
	RETURN_TOK (LITERAL);
}

static int
all_zeroes (const char *str)
{
	int	i;

	for (i = 0; str[i] != '\0'; ++i) {
		if (str[i] != '0') {
			return 0;
		}
	}

	return 1;
}

static int
significand_is_zero (const char *int_part, const char *dec_part)
{
	return all_zeroes (int_part)
		&& all_zeroes (dec_part);
}

/* Note: Exponent *digits* in literals according to COBOL 202x: 36 */
/* Note: Exponent *digits* in literals according to COBOL 202x: 36 */
#if COB_FLOAT_DIGITS_MAX != 36
#error COB_FLOAT_DIGITS_MAX adjustment needed, common.h must match scanner.l
#endif
#define COB_FLOAT_DIGITS_CHCK_MAX    38 /* incl. sign and comma */
#define COB_FLOAT_DIGITS_STR_WIDTH   39
#define COB_FLOAT_DIGITS_STR_MAX     40

#define COB_FLOAT_DIGITS_WIDTH	"%" CB_XSTRINGIFY(COB_FLOAT_DIGITS_STR_WIDTH)

static int
scan_floating_numeric (const char *text)
{
	size_t		sig_int_len;
	size_t		sig_dec_len;
	int		sig_sign;
	int		exp_sign;
	int		scale;
	int		exponent;
	int		n;
	char		significand_str[COB_FLOAT_DIGITS_STR_MAX] = { '\0' };
	char		*significand_pos;
	char		significand_dec[COB_FLOAT_DIGITS_STR_MAX] = { '\0' };
	char		significand_int[COB_FLOAT_DIGITS_STR_MAX] = { '\0' };
	char		exponent_str[8] = { '\0' };
	char		*exponent_pos;

	char		result[128] = { '\0' };
	unsigned int	literal_error = 0;

	/* Separate into significand and exponent */
	n = sscanf (text, COB_FLOAT_DIGITS_WIDTH "[0-9.,+-]%*1[Ee]%7[0-9.,+-]",
		  significand_str, exponent_str);
	/* We check the return for silencing warnings, but
	   this should actually never happen as the flex rule ensures this */
	/* LCOV_EXCL_START */
	if (n == 0) {
#if 1
		/* This should never happen (and therefore doesn't get a translation) */
		cb_error ("flex rule for scan_floating_numeric is wrong");
		COBC_ABORT();
#else
		yylval = cb_error_node;
		RETURN_TOK (LITERAL);
#endif
	}
	/* LCOV_EXCL_STOP */

	/* Get signs and adjust string positions accordingly */
	significand_pos = &significand_str[0];
	sig_sign = get_sign (*significand_pos);
	INCREMENT_IF_SIGNED (significand_pos, sig_sign);

	exponent_pos = &exponent_str[0];
	exp_sign = get_sign (*exponent_pos);
	INCREMENT_IF_SIGNED (exponent_pos, exp_sign);

	/* Separate significand into integer and decimal */
	n = sscanf (significand_pos,
		  COB_FLOAT_DIGITS_WIDTH "[0-9]%*1[.,]" COB_FLOAT_DIGITS_WIDTH "[0-9]",
		  significand_int, significand_dec);
	if (n == 0) { /* no integer part, copy after decimal-point */
		significand_int[0] = 0;
		strcpy (significand_dec, significand_pos + 1);
#if 0 /* note: we ignore compiler warnings for possible "missing NULL-terminator 
               here as we know that sscanf handles the correct with */
		significand_dec[COB_FLOAT_DIGITS_STR_MAX - 1] = 0;
	} else {
	/* silencing some warnings */
		significand_int[COB_FLOAT_DIGITS_STR_MAX - 1] = 0;
		significand_dec[COB_FLOAT_DIGITS_STR_MAX - 1] = 0;
#endif
	}

	/* Validation and exponent handling */
	sig_int_len = strlen (significand_int);
	sig_dec_len = strlen (significand_dec);
	exponent = 0;

	if (sig_int_len + sig_dec_len > COB_FLOAT_DIGITS_MAX) {
		/* note: same message in tree.c for floating-point numeric-edited item */
		snprintf (err_msg, COB_MINI_MAX,
			_("significand has more than %d digits"), COB_FLOAT_DIGITS_MAX);
		error_literal ("float", text, literal_error++);
	} else {
		if (strchr (exponent_pos, current_program->decimal_point)) {
			snprintf (err_msg, COB_MINI_MAX,
				_("exponent has decimal point"));
			error_literal ("float", text, literal_error++);
		} else {
			if (strlen (exponent_pos) > 4) {
				/* note: same message in tree.c for floating-point numeric-edited item */
				snprintf (err_msg, COB_MINI_MAX,
					_("exponent has more than 4 digits"));
				error_literal ("float", text, literal_error++);
			} else {
				n = sscanf (exponent_pos, "%d", &exponent);
				/* We check the return for silencing warnings, but
				   this should actually never happen as the flex rule ensures this */
				/* LCOV_EXCL_START */
				if (n == 0) {
#if 1
					/* This should never happen (and therefore doesn't get a translation) */
					cb_error ("flex rule for scan_floating_numeric is wrong");
					COBC_ABORT();
#else
					yylval = cb_error_node;
					RETURN_TOK (LITERAL);
#endif
				}
				/* LCOV_EXCL_STOP */
			}

			if (exp_sign == -1) {
				exponent = -exponent;
			}

			/* "The maximum permitted value and minimum permitted value of
			    the exponent is implementor-defined" */
			/* Exponent range -383  thru +384  for FLOAT-DECIMAL-16 */
			/* Exponent range -6143 thru +6144 for FLOAT-DECIMAL-34 */
			if (!(-6143 <= exponent && exponent <= 6144)) {
				snprintf (err_msg, COB_MINI_MAX,
					_("exponent not between -6143 and 6144"));
				error_literal ("float", text, literal_error++);
			}
		}
	}

	if (significand_is_zero (significand_int, significand_dec)) {
		if (sig_sign == -1) {
			snprintf (err_msg, COB_MINI_MAX,
				_("significand of 0 must be positive"));
			error_literal ("float", text, literal_error++);
		}
		if (exponent != 0) {
			snprintf (err_msg, COB_MINI_MAX,
				_("exponent of 0 must be 0"));
			error_literal ("float", text, literal_error++);
		}
		if (exp_sign == -1) {
			snprintf (err_msg, COB_MINI_MAX,
				_("exponent of 0 must be positive"));
			error_literal ("float", text, literal_error++);
		}
	}

	if (literal_error) {
		yylval = cb_build_numeric_literal (0, "0", 0);
		RETURN_TOK (LITERAL);
	}

	/* Literal data */
	strcpy (result, significand_int);
	strcat (result, significand_dec);

	/* Determine scale */
	/* Base scale is decimal part of the significant */
	scale = (int)sig_dec_len;
	if (exponent < 0) {
		/* Decimals; power down by scale difference */
		scale = - (exponent - scale);
	} else if (exponent > 0) {
		/* No decimals; power up by scale difference */
		if (exponent >= scale) {
			scale = - (exponent - scale);
		} else {
			scale -= exponent;
		}
	}

	yylval = cb_build_numeric_literal (sig_sign, result,
					   scale);
	RETURN_TOK (LITERAL);
}

static void
scan_picture (const char *text)
{
	unsigned char			*p;

	/* Scan a PICTURE clause */
	/* Normalize the input */
	for (p = (unsigned char *)text; *p; p++) {
		/* unput trailing '.' or ',' */
		if (p[1] == 0 && (*p == '.' || *p == ',')) {
			unput (*p);
			*p = 0;
			break;
		}
		*p = cb_toupper (*p);
	}

	yylval = CB_TREE (cb_build_picture (text));
}

static void
count_lines (const char *text)
{
	const char	*p;

	/* Count newlines in text */
	for (p = text; *p; p++) {
		if (*p == '\n') {
			cb_source_line++;
		}
	}
}

static void
cb_add_const_var (const char *name, cb_tree value)
{
	cb_tree			x;
	struct cb_level_78	*p78;
	struct cb_field		*f;

	/* Add an inline constant */
	x = cb_build_constant (cb_build_reference (name), value);
	f = CB_FIELD (x);
	f->flag_item_78 = 1;
	f->flag_is_global = 1;
	f->flag_internal_constant = 1;
	f->level = 1;
	(void)cb_validate_78_item (f, 1);

	/* Add constant item */
	p78 = cobc_malloc (sizeof(struct cb_level_78));
	p78->fld_78 = f;
	p78->prog = NULL;
	p78->name_len = (cob_u32_t)strlen (f->name);
	/* RXWRXW - Check this */
	p78->chk_const = 0;
	if (!const_78_ptr) {
		p78->last = p78;
	} else {
		p78->last = const_78_ptr->last;
	}
	p78->next = const_78_ptr;
	p78->glob_next = const_78_ptr;
	const_78_ptr = p78;
	if (glob_lev_78_ptr) {
		glob_lev_78_ptr->last->glob_next = const_78_ptr;
	} else if (lev_78_ptr) {
		lev_78_ptr->last->glob_next = const_78_ptr;
	} else {
		top_78_ptr = const_78_ptr;
	}
}

static void
scan_define_options (const char *text)
{
	char				*p;
	char				*s;
	char				*var;
	const struct cb_level_78	*p78;
	char				*q;
	unsigned char			*t;
	cb_tree				x;
	size_t				size;
	int				scale;
	int				sign, override;

	/* Scan a source inline define */
	p = cobc_strdup (text);

	q = &p [strlen (p)-1];
	while(q != p
	   && (isspace ((unsigned char)(*q)) || *q == '\n' || *q == '\r'))
		q--;
	q = q - 7;
	if (memcmp (q, "OVERRIDE", 8) == 0) {
		override = 1;
		while (isspace((unsigned char)(q[-1]))) q--;
		strcpy (q,"\n");
	} else {
		override = 0;
	}

	/* Ignore first part */
	s = strtok (p, " ");

	/* Variable name */
	s = strtok (NULL, " \n");
	if (!s) {
		cobc_free (p);
		return;
	}

	/* Check for already defined constant */
	if (!override) {
		for (p78 = top_78_ptr; p78; p78 = p78->glob_next) {
			if (strcasecmp (s, p78->fld_78->name) == 0) {
				cobc_free (p);
				return;
			}
		}
	}

	var = cobc_strdup (s);

	/* Value */
	s = strtok (NULL, "\n");
	if (!s) {
		cb_error (_("invalid CONSTANT: %s"), var);
		goto freevar;
	}

	if (*s == '"' || *s == '\'') {
		/* Alphanumeric literal */
		sign = *s;
		size = strlen (s);
		q = s + size - 1;
		if (q == s || *q != sign) {
			cb_error (_("invalid alphanumeric CONSTANT: %s"), s);
			goto freevar;
		}
		if (size < 3) {
			cb_error (_("empty alphanumeric CONSTANT: %s"), s);
			goto freevar;
		}
		*q = 0;
		size -= 2;
		x = cb_build_alphanumeric_literal (s + 1, size);
	} else {
		/* Get sign */
		sign = get_sign (*s);
		INCREMENT_IF_SIGNED (s, sign);

		/* Get decimal point */
		scale = 0;
		q = strchr (s, '.');
		if (q) {
			scale = (int)strlen (q) - 1;
			if (scale < 1) {
				cb_error (_("invalid numeric CONSTANT: %s"), s);
				goto freevar;
			}
			/* Remove decimal point */
			memmove (q, q + 1, (size_t)scale + 1);
		}
		for (t = (unsigned char *)s; *t; ++t) {
			if (*t < '0' || *t  > '9') {
				cb_error (_("invalid numeric CONSTANT: %s"), s);
				goto freevar;
			}
		}
		if (strlen (s) > COB_MAX_DIGITS) {
			cb_error (_("invalid numeric CONSTANT: %s"), s);
			goto freevar;
		}

		x = cb_build_numeric_literal (sign, s, scale);
	}
	/* Add to constant list */
	cb_add_const_var (var, x);

freevar:
	cobc_free (p);
	cobc_free (var);
}

#undef INCREMENT_IF_SIGNED

/*
  For yytext of the form '#directive "a-word"' or '#directive
  (a-word)', copy a-word into word, converting it to upper-case.
*/
static void
copy_word_in_quotes (char ** const word)
{
	char	*text = cobc_strdup (yytext);
	char	*word_str;
	size_t	word_len;

	/* Skip directive */
	word_str = strtok (text, " ");

	/* Get word and remove quotes */
	word_str = strtok (NULL, "\n");
	word_len = strlen (word_str) - 2;
	*word = cobc_malloc (word_len + 1);
	cb_memcpy_upper (*word, word_str + 1, word_len);

	cobc_free (text);
}

/*
   For yytext of the form '#directive "first-word" "second-word"' or '#directive
   (first-word) (second-word)', allocate copies of first-word for word1 and
   second-word for word2, converting them to upper-case.
*/
static void
copy_two_words_in_quotes (char ** const word1, char ** const word2)
{
	char	*text = cobc_strdup (yytext);
	char	*word1_str;
	char	*word2_str;
	size_t	word_len;

	/* Skip directive. */
	word1_str = strtok (text, " ");

	/* Get words and remove surrounding quotes. */

	word1_str = strtok (NULL, " ");
	word_len = strlen (word1_str) - 2;
	*word1 = cobc_malloc (word_len + 1);
	cb_memcpy_upper (*word1, word1_str + 1, word_len);

	word2_str = strtok (NULL, "\n");
	word_len = strlen (word2_str) - 2;
	*word2 = cobc_malloc (word_len + 1);
	cb_memcpy_upper (*word2, word2_str + 1, word_len);

	cobc_free (text);
}

static void
add_synonym (const int std, const int synonym_replaces_original)
{
	char	*word;
	char	*synonym;

	copy_two_words_in_quotes (&word, &synonym);

	if (!is_default_reserved_word (word)) {
		cb_error (_("'%s' is not a default reserved word, so cannot be aliased"),
			  word);
	} else if (is_reserved_word (synonym)) {
		cb_error (_("'%s' is already reserved"), synonym);
		if (!std) {
			cb_note (COB_WARNOPT_NONE, 0, _("you may want MAKESYN instead"));
		}
	} else {
		if (synonym_replaces_original) {
			remove_reserved_word_now (word);
		}
		add_reserved_word_now (synonym, word);
	}

	cobc_free (word);
	cobc_free (synonym);
}

static void
make_synonym (void)
{
	char* new_meaning;
	char* word_to_change;

	copy_two_words_in_quotes (&new_meaning, &word_to_change);

	if (!is_default_reserved_word (new_meaning)) {
		cb_error (_("'%s' is not a default reserved word, so cannot be aliased"),
			new_meaning);
	} else if (!is_reserved_word (word_to_change)) {
		cb_error (_("'%s' is not a reserved word"), word_to_change);
		cb_note (COB_WARNOPT_NONE, 0, _("you may want ADDSYN or OVERRIDE instead"));
	} else {
		remove_reserved_word_now (word_to_change);
		add_reserved_word_now (word_to_change, new_meaning);
	}

	cobc_free (new_meaning);
	cobc_free (word_to_change);
}

static void
clear_constants (void)
{
	struct cb_level_78	*p78;

	while (lev_78_ptr) {
		p78 = lev_78_ptr;
		lev_78_ptr = lev_78_ptr->next;
		cobc_free (p78);
	}
	while (glob_lev_78_ptr) {
		p78 = glob_lev_78_ptr;
		glob_lev_78_ptr = glob_lev_78_ptr->next;
		cobc_free (p78);
	}
	while (const_78_ptr) {
		p78 = const_78_ptr;
		const_78_ptr = const_78_ptr->next;
		cobc_free (p78);
	}
	top_78_ptr = NULL;
}

/* Global functions */

void
ylex_clear_all (void)
{
	/* Clear buffers after parsing all source elements */
	if (pic_buff2) {
		cobc_free (pic_buff2);
		pic_buff2 = NULL;
	}
	if (pic_buff1) {
		cobc_free (pic_buff1);
		pic_buff1 = NULL;
	}
	if (plex_buff) {
		cobc_free (plex_buff);
		plex_buff = NULL;
	}
	plex_size = 0;
	pic1_size = 0;
	pic2_size = 0;

#if 1
	clear_constants ();
#else
	cb_reset_78 ();
	cb_reset_global_78 ();
#endif
}

void
ylex_call_destroy (void)
{
	/* Release flex buffers */
	(void)yylex_destroy ();
#if 0
	const_78_ptr = NULL;
#endif
}

void
cb_unput_dot (void)
{
	unput ('.');
}

/* Remove constant (78 level) items for current program */
void
cb_reset_78 (void)
{
	struct cb_level_78	*p78;

	while (lev_78_ptr) {
		p78 = lev_78_ptr;
		lev_78_ptr = lev_78_ptr->next;
		cobc_free (p78);
	}

	if (glob_lev_78_ptr) {
		top_78_ptr = p78 = glob_lev_78_ptr;
		while (p78) {
			p78->not_const = 0;
			p78 = p78->next;
		}
	} else {
		top_78_ptr = const_78_ptr;
	}
}

/* Remove constant (78 level) items for top program */
void
cb_reset_global_78 (void)
{
	struct cb_level_78* p78;

	while (glob_lev_78_ptr) {
		p78 = glob_lev_78_ptr;
		glob_lev_78_ptr = glob_lev_78_ptr->next;
		cobc_free (p78);
	}
	top_78_ptr = const_78_ptr;
}

/* Add a constant (78 level) item */
void
cb_add_78 (struct cb_field *f)
{
	struct cb_level_78	*p78;

	p78	= cobc_malloc (sizeof(struct cb_level_78));
	p78->fld_78 = f;
	p78->prog = current_program;
	p78->name_len = (cob_u32_t)strlen (f->name);
	if (f->flag_is_global) {
		if (!glob_lev_78_ptr) {
			p78->last = p78;
		} else {
			p78->last = glob_lev_78_ptr->last;
		}
		p78->last->glob_next = const_78_ptr;
		p78->next = glob_lev_78_ptr;
		p78->glob_next = glob_lev_78_ptr;
		p78->chk_const = 1;
		glob_lev_78_ptr = p78;
		if (lev_78_ptr) {
			lev_78_ptr->last->glob_next = glob_lev_78_ptr;
		} else {
			top_78_ptr = glob_lev_78_ptr;
		}
	} else {
		if (!lev_78_ptr) {
			p78->last = p78;
		} else {
			p78->last = lev_78_ptr->last;
		}
		if (glob_lev_78_ptr) {
			p78->last->glob_next = glob_lev_78_ptr;
		} else {
			p78->last->glob_next = const_78_ptr;
		}
		p78->next = lev_78_ptr;
		p78->glob_next = lev_78_ptr;
		lev_78_ptr = p78;
		top_78_ptr = lev_78_ptr;
	}
}

struct cb_field *
check_level_78 (const char *name)
{
	const struct cb_level_78	*p78;

	/* Check against a current constant (78 level) */
	for (p78 = lev_78_ptr; p78; p78 = p78->next) {
		if (strcasecmp (name, p78->fld_78->name) == 0) {
			return p78->fld_78;
		}
	}
	/* Check against a global constant (78 level) */
	for (p78 = glob_lev_78_ptr; p78; p78 = p78->next) {
		if (strcasecmp (name, p78->fld_78->name) == 0) {
			return p78->fld_78;
		}
	}
	return NULL;
}

/*
  Find program with the program-name name in defined_prog_list. If it is not
  there, return NULL.
*/
struct cb_program *
cb_find_defined_program_by_name (const char *name)
{
	int	(*cmp_func)(const char *, const char *);
	cb_tree	l;
	cb_tree	x;

	if (cb_fold_call) {
		cmp_func = &strcasecmp;
	} else {
		cmp_func = &strcmp;
	}

	for (l = defined_prog_list; l; l = CB_CHAIN (l)) {
		x = CB_VALUE (l);
		if ((*cmp_func)(name, CB_PROGRAM (x)->program_name) == 0) {
			return CB_PROGRAM (x);
		}
	}

	return NULL;
}

struct cb_program *
cb_find_defined_program_by_id (const char *orig_id)
{
	cb_tree	l;
	cb_tree	x;

	for (l = defined_prog_list; l; l = CB_CHAIN (l)) {
		x = CB_VALUE (l);
		if (strcmp (orig_id, CB_PROGRAM (x)->orig_program_id) == 0) {
			return CB_PROGRAM (x);
		}
	}

	return NULL;
}

